(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    386938,       9514]
NotebookOptionsPosition[    381326,       9406]
NotebookOutlinePosition[    381719,       9422]
CellTagsIndexPosition[    381676,       9419]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Title",
 CellChangeTimes->{{3.815727963007406*^9, 
  3.815727966942301*^9}},ExpressionUUID->"f9fac6ad-b4b0-4fc4-b662-\
ff26b4fcb383"],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<MaTeX`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"MaTeX", ",", 
    RowBox[{"\"\<Preamble\>\"", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\\\\usepackage{amssymb,amsmath,latexsym,amsfonts,amsthm,xcolor,bm,\
mhchem}\>\"", ",", "\"\<\\\\definecolor{darkgreen}{RGB}{0, 180, 0}\>\""}], 
      "}"}]}]}], "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[222]:=",ExpressionUUID->"73548dbc-1321-4b7c-9133-54658820615c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cyclobutadiene", "Title",
 CellChangeTimes->{{3.8124556175038033`*^9, 3.812455626881061*^9}, {
  3.819643851046184*^9, 
  3.819643854273136*^9}},ExpressionUUID->"d98052b5-b8bf-49c7-976f-\
70f5883fce25"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  SubscriptBox["D", 
   RowBox[{"2", "h"}]], 
  TraditionalForm]],ExpressionUUID->"e0e633e9-7af5-48b9-b985-8e719c46e315"]], \
"Section",
 CellChangeTimes->{{3.8196438565054092`*^9, 
  3.819643858041607*^9}},ExpressionUUID->"0d5f8085-b423-4bab-b579-\
a185275ba81f"],

Cell[CellGroupData[{

Cell["Geometry", "Subsection",
 CellChangeTimes->{{3.820119526099333*^9, 
  3.820119528866288*^9}},ExpressionUUID->"010a9483-a730-4fa6-9b2a-\
13873895483d"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", 
    RowBox[{"2", "h"}]], TraditionalForm]],ExpressionUUID->
  "79cec10a-b06a-41fc-b205-d09d038dc7bc"],
 " geometry (in angstrom) obtained at the CC3(full)/aug-cc-pVTZ"
}], "Text",
 CellChangeTimes->{{3.820119534614387*^9, 3.820119562489399*^9}, {
  3.8211849460819263`*^9, 
  3.8211849475990343`*^9}},ExpressionUUID->"203dfa49-b391-422b-90c4-\
2b6a46c41acd"],

Cell["\<\
  C          -0.78248546      -0.67208001       0.00000000
  C           0.78248546      -0.67208001       0.00000000
  C          -0.78248546       0.67208001       0.00000000
  C           0.78248546       0.67208001       0.00000000
  H          -1.54227765      -1.43404123      -0.00000000
  H           1.54227765      -1.43404123       0.00000000
  H          -1.54227765       1.43404123       0.00000000
  H           1.54227765       1.43404123      -0.00000000\
\>", "Text",
 CellChangeTimes->{3.82011957301793*^9, 
  3.821184944001792*^9},ExpressionUUID->"cd19f4a5-5b55-4f6b-ab28-\
a67e3893faaf"]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.815728210943774*^9, 
  3.815728212904736*^9}},ExpressionUUID->"146f0b45-c767-44b4-adf3-\
b56aaf7be25a"],

Cell[CellGroupData[{

Cell["Standard methods", "Subsubsection",
 CellChangeTimes->{{3.820894846481266*^9, 
  3.820894851456294*^9}},ExpressionUUID->"85eac05c-0c0d-4570-9562-\
016c59c123c0"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"%", "T1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CC3", "/", "aug"}], "-", "cc", "-", "pVTZ"}], ")"}], "  ", 
    "98.7", "%"}], ",", " ", 
   RowBox[{"95.0", "%"}], ",", " ", 
   RowBox[{"0.84", "%"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.820399762323615*^9, 3.820399794919445*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"5e934c70-0bb3-4c28-a094-c1ba13c9aa1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CBDD2h", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", "CC3", " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<CC3\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.420", ",", "3.341", 
       ",", "4.658"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.396", ",", "3.158", ",",
        "4.711"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.402", ",", "3.119", ",",
        "4.777"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.409", ",", "3.113", ",",
        "4.774"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CCSDT", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSDT\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.442", ",", "3.357", 
       ",", "4.311"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.411", ",", "3.175", ",",
        "4.327"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.411", ",", "3.139", ",",
        "4.429"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CC4", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CC4\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", ",", "3.343", 
       ",", "4.067"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CC4\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "\"\<\>\"", ",", 
       "3.164", ",", "4.041"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CCSDTQ", " ", "*)"}], "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSDTQ\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", ",", 
       "3.340", ",", "4.073"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"CASSCF", 
       RowBox[{"(", 
        RowBox[{"4", ",", "4"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SA2-CASSCF(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.662", ",", 
       "4.657", ",", "4.439"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.672", ",", "4.563", ",",
        "4.448"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.670", ",", "4.546", ",",
        "4.441"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.671", ",", "4.549", ",",
        "4.440"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"CASPT2", 
       RowBox[{"(", 
        RowBox[{"4", ",", "4"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CASPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.440", ",", 
       "3.162", ",", "4.115"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.414", ",", "2.971", ",",
        "4.068"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.412", ",", "2.923", ",",
        "4.072"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.417", ",", "2.911", ",",
        "4.081"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"XMS", "-", 
       RowBox[{"CASPT2", 
        RowBox[{"(", 
         RowBox[{"4", ",", "4"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<XMS-CASPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", 
       ",", "\"\<\>\"", ",", "4.151"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.105"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.114"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.125"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"4", ",", "4"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SC-NEVPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.407", ",", 
       "2.707", ",", "4.145"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.381", ",", "2.479", ",",
        "4.109"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.379", ",", "2.422", ",",
        "4.108"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.384", ",", "2.408", ",",
        "4.125"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"PC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"4", ",", "4"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<PC-NEVPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.409", ",", 
       "2.652", ",", "4.120"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.384", ",", "2.424", ",",
        "4.084"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.382", ",", "2.368", ",",
        "4.083"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.387", ",", "2.353", ",",
        "4.091"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"MRCI", 
       RowBox[{"(", 
        RowBox[{"4", ",", "4"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<MRCI(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.564", ",", 
       "3.802", ",", "4.265"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.558", ",", "3.670", ",",
        "4.254"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.568", ",", "3.678", ",",
        "4.270"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.574", ",", "3.681", ",",
        "4.280"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"CASSCF", 
       RowBox[{"(", 
        RowBox[{"12", ",", "12"}], ")"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SA2-CASSCF(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.675", 
       ",", "3.924", ",", "4.220"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.685", ",", "3.856", ",",
        "4.221"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.686", ",", "3.844", ",",
        "4.217"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.687", ",", "3.846", ",",
        "4.216"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"CASPT2", 
       RowBox[{"(", 
        RowBox[{"12", ",", "12"}], ")"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CASPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.508", ",", 
       "3.407", ",", "4.099"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.489", ",", "3.256", ",",
        "4.044"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.480", ",", "3.183", ",",
        "4.043"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.482", ",", "3.163", ",",
        "4.047"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"XMS", "-", 
       RowBox[{"CASPT2", 
        RowBox[{"(", 
         RowBox[{"12", ",", "12"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<XMS-CASPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", 
       ",", "\"\<\>\"", ",", "4.111"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.056"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.059"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.065"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"12", ",", "12"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SC-NEVPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.522", ",",
        "3.409", ",", "4.130"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.511", ",", "3.266", ",",
        "4.093"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.501", ",", "3.188", ",",
        "4.086"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.503", ",", "3.167", ",",
        "4.088"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"PC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"12", ",", "12"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<PC-NEVPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "1.487", ",",
        "3.296", ",", "4.103"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "1.472", ",", "3.141", ",",
        "4.064"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "1.462", ",", "3.063", ",",
        "4.056"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "1.464", ",", "3.043", ",",
        "4.059"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"MRCI", 
       RowBox[{"(", 
        RowBox[{"12", ",", "12"}], ")"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<MRCI(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\"", ",", "4.125"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CIPSI", " ", "*)"}], "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<CIPSI\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"1.486", " ", ",", " ", "0.005"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"3.348", ",", "0.024"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"4.084", ",", "0.012"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"1.458", ",", "0.009"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"3.187", ",", "0.035"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"4.041", ",", "0.036"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"1.461", ",", "0.030"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"3.142", ",", "0.035"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"4.028", ",", "0.086"}], "]"}]}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.819646448046678*^9, 3.819646463831727*^9}, {
   3.819646500151936*^9, 3.81964650448241*^9}, {3.819907670630348*^9, 
   3.819907680355007*^9}, {3.819962436524386*^9, 3.819962471830098*^9}, {
   3.8201195944406433`*^9, 3.820119675784534*^9}, {3.8201197144809713`*^9, 
   3.820119767498103*^9}, {3.82011984563081*^9, 3.8201200473136063`*^9}, {
   3.8201200855889997`*^9, 3.820120304294695*^9}, {3.8202508303996363`*^9, 
   3.820250847512038*^9}, {3.820250944603057*^9, 3.820251093336108*^9}, {
   3.820251292806981*^9, 3.82025129610933*^9}, {3.820386247967042*^9, 
   3.8203862577081842`*^9}, {3.820386652104602*^9, 3.820386669162932*^9}, {
   3.820387145953229*^9, 3.820387315628099*^9}, {3.820387362282827*^9, 
   3.8203875002604113`*^9}, {3.820387567195519*^9, 3.820387608666377*^9}, {
   3.820387681896881*^9, 3.820387685742483*^9}, {3.820387721021719*^9, 
   3.820387855833411*^9}, {3.8203878974670057`*^9, 3.8203879474560003`*^9}, {
   3.820387996014256*^9, 3.820388152182413*^9}, {3.820393442050746*^9, 
   3.8203934433201036`*^9}, {3.8204808469176493`*^9, 3.82048085417349*^9}, {
   3.820480919898058*^9, 3.8204809258018923`*^9}, {3.82056466758092*^9, 
   3.820564671398425*^9}, {3.820564714190504*^9, 3.820564717078519*^9}, {
   3.820593204968033*^9, 3.8205932212657623`*^9}, {3.820593256762594*^9, 
   3.8205932815501966`*^9}, {3.8205933917678137`*^9, 3.82059339211928*^9}, {
   3.820596541999056*^9, 3.8205965456075573`*^9}, {3.820596584793776*^9, 
   3.820596592035565*^9}, {3.8206639516132917`*^9, 3.8206640251324778`*^9}, {
   3.820664076437257*^9, 3.820664092355732*^9}, {3.820664129694065*^9, 
   3.820664234257699*^9}, {3.820664277712181*^9, 3.820664390412386*^9}, {
   3.82066472030632*^9, 3.8206650378666363`*^9}, {3.8206651350466223`*^9, 
   3.8206651355358143`*^9}, {3.8206651770421886`*^9, 3.820665180124625*^9}, {
   3.820671406426931*^9, 3.820671414474155*^9}, {3.8206714680944977`*^9, 
   3.820671507332296*^9}, {3.820768020623414*^9, 3.820768024400755*^9}, {
   3.821184592564178*^9, 3.821184596778758*^9}, {3.821360176829712*^9, 
   3.821360180740265*^9}, {3.821360889065583*^9, 3.821360891904513*^9}, {
   3.821765108977744*^9, 3.8217651191143627`*^9}, {3.8217651528259697`*^9, 
   3.821765153289287*^9}, {3.8217656216074123`*^9, 3.821765621775786*^9}, {
   3.822149717025532*^9, 3.822149718926025*^9}, {3.822534668055361*^9, 
   3.822534721216193*^9}, {3.822668251568551*^9, 3.8226682557304163`*^9}, {
   3.823173617317602*^9, 3.8231736421679077`*^9}, {3.8233266024835052`*^9, 
   3.823326609828835*^9}, {3.823483103860236*^9, 3.823483108796145*^9}, {
   3.823529733441641*^9, 3.8235297380443172`*^9}, 3.824441777889266*^9, {
   3.824481557380546*^9, 3.8244815610168753`*^9}, {3.824871656630433*^9, 
   3.8248716798780317`*^9}, {3.825647331768765*^9, 3.82564734442376*^9}, 
   3.8257401278773537`*^9},
 CellLabel->"In[3]:=",ExpressionUUID->"283f461f-fa73-44be-9b2e-3fccbe85020e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spin-flip methods", "Subsubsection",
 CellChangeTimes->{{3.820894857113195*^9, 
  3.820894861987111*^9}},ExpressionUUID->"496a2a44-bf08-47c1-928f-\
5e9378cdcbe6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CBDD2hSF", "=", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"(*", " ", 
     RowBox[{"SF", "-", "CIS"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<SF-CIS\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0812"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.1678", "+", "1.3467"}], ",", "2.0446"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.5077", "+", "1.3467"}], ",", "0.0449"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"4.0323", "+", "1.3467"}], ",", "0.0915"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0829"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.1842", "+", "1.3031"}], ",", "2.0497"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4177", "+", "1.3031"}], ",", "0.0549"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"4.0452", "+", "1.3031"}], ",", "0.0946"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0852"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.2021", "+", "1.2700"}], ",", "2.0537"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4312", "+", "1.2700"}], ",", "0.0575"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"4.0721", "+", "1.2700"}], ",", "0.0985"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0855"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.2039", "+", "1.2673"}], ",", "2.0541"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4342", "+", "1.2673"}], ",", "0.0579"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"4.0750", "+", "1.2673"}], ",", "0.1001"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"CIS", 
        RowBox[{"(", "D", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "B3LYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-B3LYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0103"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9898", "+", "0.7163"}], ",", "1.9901"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4945", "+", "0.7163"}], ",", "0.0272"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2768", "+", "0.7163"}], ",", "0.0166"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0102"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9673", "+", "0.7383"}], ",", "1.9896"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4655", "+", "0.7383"}], ",", "0.0281"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2542", "+", "0.7383"}], ",", "0.0162"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0108"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9826", "+", "0.7201"}], ",", "1.9890"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4788", "+", "0.7201"}], ",", "0.0299"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2679", "+", "0.7201"}], ",", "0.0168"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0108"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9849", "+", "0.7182"}], ",", "1.9891"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4812", "+", "0.7182"}], ",", "0.0299"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2706", "+", "0.7182"}], ",", "0.0169"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "PBE0"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-PBE0\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0115"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0782", "+", "0.6087"}], ",", "2.0018"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7051", "+", "0.6087"}], ",", "0.0173"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4805", "+", "0.6087"}], ",", "0.0179"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0118"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0593", "+", "0.6251"}], ",", "2.0014"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.6761", "+", "0.6251"}], ",", "0.0191"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4598", "+", "0.6251"}], ",", "0.0181"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0126"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0852", "+", "0.5966"}], ",", "2.0013"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.6994", "+", "0.5966"}], ",", "0.0209"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4848", "+", "0.5966"}], ",", "0.0191"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0127"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0878", "+", "0.5940"}], ",", "2.0015"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7022", "+", "0.5940"}], ",", "0.0209"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4848", "+", "0.5940"}], ",", "0.0192"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "BHHLYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-BHHLYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0276"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5312", "+", "1.0209"}], ",", "2.0150"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7582", "+", "1.0209"}], ",", "0.0225"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4074", "+", "1.0209"}], ",", "0.0401"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0278"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5216", "+", "1.0249"}], ",", "2.0161"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7186", "+", "1.0249"}], ",", "0.0245"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.3968", "+", "1.0249"}], ",", "0.0401"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0285"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5353", "+", "1.0049"}], ",", "2.0172"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7268", "+", "1.0049"}], ",", "0.0256"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4876", "+", "1.0049"}], ",", "0.0410"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0286"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5374", "+", "1.0026"}], ",", "2.0173"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7296", "+", "1.0026"}], ",", "0.0257"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.4123", "+", "1.0026"}], ",", "0.0412"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "M06", "-", 
       RowBox[{"2", "X"}]}], " ", "*)"}], "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-M06-2X\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0281"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4566"}], "+", "1.9337"}], ",", "2.0115"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9015", "+", "1.9337"}], ",", "0.0135"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4444", "+", "1.9337"}], ",", "0.0388"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0282"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4555"}], "+", "1.9224"}], ",", "2.0129"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.8623", "+", "1.9224"}], ",", "0.0156"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4372", "+", "1.9224"}], ",", "0.0387"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0288"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.3898"}], "+", "1.8515"}], ",", "2.0140"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9194", "+", "1.8515"}], ",", "0.0174"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.5055", "+", "1.8515"}], ",", "0.0396"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0288"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4124"}], "+", "1.8706"}], ",", "2.0138"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9000", "+", "1.8706"}], ",", "0.0173"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4815", "+", "1.8706"}], ",", "0.0397"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "CAM", "-", "B3LYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-CAM-B3LYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0138"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9020", "+", "0.8479"}], ",", "1.9895"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4886", "+", "0.8479"}], ",", "0.0292"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2920", "+", "0.0228"}], ",", "0.0166"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0140"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.8835", "+", "0.8612"}], ",", "1.9901"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4615", "+", "0.8612"}], ",", "0.0310"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2791", "+", "0.8612"}], ",", "0.0230"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0145"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.8956", "+", "0.8469"}], ",", "1.9899"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4713", "+", "0.8469"}], ",", "0.0326"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2910", "+", "0.8469"}], ",", "0.0235"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0146"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.8974", "+", "0.8452"}], ",", "1.9899"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4733", "+", "0.8452"}], ",", "0.0327"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.2931", "+", "0.8452"}], ",", "0.0236"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "\[Omega]B97X", "-", "V"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-\[Omega]B97X-V\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0134"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7600", "+", "1.0505"}], ",", "1.9871"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3263", "+", "1.0505"}], ",", "0.0281"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.1694", "+", "1.0505"}], ",", "0.0224"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0142"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7418", "+", "1.0580"}], ",", "1.9868"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2979", "+", "1.0580"}], ",", "0.0328"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.1586", "+", "1.0580"}], ",", "0.0234"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0146"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7578", "+", "1.0390"}], ",", "1.9864"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3121", "+", "1.0390"}], ",", "0.0346"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.1738", "+", "1.0390"}], ",", "0.0239"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "M11"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-M11\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0247"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0363"}], "+", "1.6026"}], ",", "2.0082"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0842", "+", "1.6026"}], ",", "0.0185"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.6893", "+", "1.6026"}], ",", "0.0416"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0252"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0338"}], "+", "1.5796"}], ",", "2.0104"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0604", "+", "1.5796"}], ",", "0.0227"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.6876", "+", "1.5796"}], ",", "0.0436"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0255"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0198"}], "+", "1.5789"}], ",", "2.0112"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0721", "+", "1.5789"}], ",", "0.0231"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.7212", "+", "1.5789"}], ",", "0.0447"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0255"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0040"}], "+", "1.5612"}], ",", "2.0114"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0889", "+", "1.5612"}], ",", "0.0220"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.7374", "+", "1.5612"}], ",", "0.0435"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "LC", "-", "\[Omega]PBE08"}], " ", "*)"}],
      "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-LC-\[Omega]PBE08\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0164"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2125", "+", "0.7048"}], ",", "1.9831"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7404", "+", "0.7048"}], ",", "0.0347"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.6480", "+", "0.7048"}], ",", "0.0283"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0180"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2069", "+", "0.6901"}], ",", "1.9848"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7246", "+", "0.6901"}], ",", "0.0416"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.6554", "+", "0.6901"}], ",", "0.0304"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0189"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2296", "+", "0.6671"}], ",", "1.9843"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7474", "+", "0.6671"}], ",", "0.0443"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.6808", "+", "0.6671"}], ",", "0.0312"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0189"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2316", "+", "0.6650"}], ",", "1.9846"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7495", "+", "0.6650"}], ",", "0.0442"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.6828", "+", "0.6650"}], ",", "0.0313"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "B2PLYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-B2PLYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0307"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.6056", "+", "0.9319"}], ",", "2.0173"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8951", "+", "0.9319"}], ",", "0.0247"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.5301", "+", "0.9319"}], ",", "0.0441"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0309"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5977", "+", "0.9336"}], ",", "2.0187"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8544", "+", "0.9336"}], ",", "0.0271"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.5218", "+", "0.9336"}], ",", "0.0443"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0318"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.6151", "+", "0.9095"}], ",", "2.0200"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8664", "+", "0.9095"}], ",", "0.0284"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3.5387", "+", "0.9095"}], ",", "0.0454"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"ADC", 
        RowBox[{"(", "2", ")"}]}], "-", "s"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-ADC(2)-s\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.208053", "+", "1.369355"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.934013", "+", "1.369355"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.826881", "+", "1.369355"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.221852", "+", "1.290924"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.825240", "+", "1.290924"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.822946", "+", "1.290924"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.229434", "+", "1.301218"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.797447", "+", "1.301218"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.829496", "+", "1.301218"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.228423", "+", "1.315407"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.785153", "+", "1.315407"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.824823", "+", "1.315407"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"ADC", 
        RowBox[{"(", "2", ")"}]}], "-", "x"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-ADC(2)-x\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.503748"}], "+", "2.061201"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.170812", "+", "2.061201"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.666343", "+", "2.061201"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.501005"}], "+", "2.024877"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.014360", "+", "2.024877"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.655718", "+", "2.024877"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.486246"}], "+", "2.025630"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.005678", "+", "2.025630"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.677724", "+", "2.025630"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"ADC", 
        RowBox[{"(", "3", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", " ", 
     
     RowBox[{"{", 
      RowBox[{"\"\<SF-ADC(3)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.177101"}], "+", "1.612001"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.739502", "+", "1.612001"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.630312", "+", "1.612001"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.169470"}], "+", "1.591304"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.588302", "+", "1.591304"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.616757", "+", "1.591304"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.168414"}], "+", "1.587260"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.574672", "+", "1.587260"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.636246", "+", "1.587260"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "EOM", "-", "CCSD"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-EOM-CCSD\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.0185", "+", "1.6443"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8709", "+", "1.6443"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.6311", "+", "1.6443"}], ",", "\"\<\>\""}], "}"}]}], "}"}],
      ",", "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.0201", "+", "1.5905"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7242", "+", "1.5905"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.2655", "+", "1.5905"}], ",", "\"\<\>\""}], "}"}]}], "}"}],
      ",", "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.0246", "+", "1.5845"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7085", "+", "1.5845"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.6605", "+", "1.5845"}], ",", "\"\<\>\""}], "}"}]}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "EOM", "-", "CCSD"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-EOM-CC(2,3)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.2682"}], "+", "1.7587"}], ",", "\"\<\>\""}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5740", "+", "1.7587"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.3020", "+", "1.7587"}], ",", "\"\<\>\""}], "}"}]}], "}"}],
      ",", "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.2976"}], "+", "1.7616"}], ",", "\"\<\>\""}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3945", "+", "1.7616"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.2655", "+", "1.7616"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}]}], "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"SF", "-", "XX"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<SF-XX\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}], ",", 
        RowBox[{"{", ",", "}"}]}], "}"}]}], "*)"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.820593397182576*^9, 3.820593679672505*^9}, {
   3.820593811796682*^9, 3.820593817044042*^9}, {3.820593850826929*^9, 
   3.82059388521951*^9}, {3.8205939172857924`*^9, 3.820594027998721*^9}, {
   3.820594067267211*^9, 3.820594191276618*^9}, {3.820594252507471*^9, 
   3.820594420200716*^9}, {3.820594525729059*^9, 3.82059480866117*^9}, {
   3.820594939409107*^9, 3.820594941148822*^9}, {3.820595180502719*^9, 
   3.820595204839292*^9}, {3.8206716140551987`*^9, 3.820671659350423*^9}, {
   3.82067169156428*^9, 3.820671724323728*^9}, {3.8206717588300657`*^9, 
   3.820671786666383*^9}, {3.820671861519487*^9, 3.820671869575233*^9}, {
   3.8207666787383757`*^9, 3.820766687274889*^9}, {3.820766738665867*^9, 
   3.820766749566669*^9}, {3.8207670579838877`*^9, 3.820767066045186*^9}, {
   3.820767099660761*^9, 3.820767124503524*^9}, {3.820767204067615*^9, 
   3.820767360345351*^9}, {3.820767392577623*^9, 3.82076762151588*^9}, {
   3.8208949708115807`*^9, 3.820895005407003*^9}, {3.820895141036934*^9, 
   3.820895141067258*^9}, {3.821172531929908*^9, 3.8211725567720003`*^9}, 
   3.821172632065477*^9, {3.821172794023378*^9, 3.8211727973820972`*^9}, {
   3.821172874033523*^9, 3.821172897619728*^9}, {3.821172966033085*^9, 
   3.8211729681572866`*^9}, {3.8211730074170103`*^9, 3.821173012588673*^9}, {
   3.821173057124378*^9, 3.8211731017701063`*^9}, {3.821178639524795*^9, 
   3.8211788654654703`*^9}, {3.821178907497795*^9, 3.8211791228460407`*^9}, {
   3.821376263207099*^9, 3.821376292877036*^9}, {3.8217634351790543`*^9, 
   3.821763466773179*^9}, {3.8217636135142097`*^9, 3.82176366987997*^9}, 
   3.821764118242491*^9, {3.821764235949004*^9, 3.821764254996149*^9}, {
   3.822149310642477*^9, 3.82214945384396*^9}, {3.82214955763916*^9, 
   3.8221495577931423`*^9}, {3.822149611904914*^9, 3.822149659541936*^9}, {
   3.822535438427226*^9, 3.8225354388276377`*^9}, {3.823670224645812*^9, 
   3.8236702284306507`*^9}, {3.823670260700815*^9, 3.823670458589139*^9}, {
   3.823670489452241*^9, 3.823670522803753*^9}, {3.823670555706526*^9, 
   3.82367070368489*^9}, {3.823702048053302*^9, 3.823702583613647*^9}, {
   3.823702627206479*^9, 3.8237027262398376`*^9}, {3.823702787554783*^9, 
   3.8237028715730877`*^9}, {3.8243989598501797`*^9, 3.824399001686157*^9}, {
   3.824399104826311*^9, 3.824399105350865*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"1f47c0ab-65f0-4e3d-b3bf-78a937e27006"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table of excitation energies", "Subsection",
 CellChangeTimes->{{3.81246742284888*^9, 3.812467426356081*^9}, {
  3.815728206364393*^9, 3.81572820807975*^9}, {3.8196448855339518`*^9, 
  3.819644895161807*^9}},ExpressionUUID->"e9b6b4b3-0323-418a-aaa5-\
63000ac657a3"],

Cell[CellGroupData[{

Cell["Standard methods", "Subsubsection",
 CellChangeTimes->{{3.820894846481266*^9, 
  3.820894851456294*^9}},ExpressionUUID->"c2a68803-eb09-4af4-95e0-\
ded4fd26bba2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"CBDD2h", ",", "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Method\>\"", ",", "\"\<Basis\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(3\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)\>\"", ",", 
        "\"\<2 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(g\)]\)\>\""}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8124556299606953`*^9, 3.812456068618113*^9}, {
   3.8124561363369207`*^9, 3.812456197829088*^9}, {3.8124562429685*^9, 
   3.812456260620059*^9}, {3.812456331353037*^9, 3.812456384093768*^9}, {
   3.812456573030534*^9, 3.8124566133288307`*^9}, 3.812456659150004*^9, {
   3.812456797405002*^9, 3.8124568446428843`*^9}, {3.81245701524162*^9, 
   3.812457045598267*^9}, 3.812457174657404*^9, {3.812457293034042*^9, 
   3.812457340284532*^9}, 3.8124573713758183`*^9, {3.8124574135109253`*^9, 
   3.812457467988901*^9}, {3.812457525670442*^9, 3.8124575800592833`*^9}, {
   3.812471509708454*^9, 3.8124715175446997`*^9}, {3.812471613960926*^9, 
   3.812471760379608*^9}, {3.812471807962068*^9, 3.812471816235973*^9}, {
   3.812471988217773*^9, 3.812472032321349*^9}, {3.812472081700213*^9, 
   3.812472104421781*^9}, {3.812905577293921*^9, 3.812905591905593*^9}, {
   3.812905701723777*^9, 3.812905738566313*^9}, 3.812906324680492*^9, {
   3.812906383422841*^9, 3.812906439251058*^9}, {3.8129072174245987`*^9, 
   3.8129072178235207`*^9}, {3.81290783650852*^9, 3.812907839973118*^9}, {
   3.812908188519864*^9, 3.812908188749086*^9}, {3.812908398082901*^9, 
   3.812908398483513*^9}, {3.812908465537078*^9, 3.812908481116406*^9}, {
   3.8129085173473454`*^9, 3.812908557109565*^9}, {3.812908776475946*^9, 
   3.812908776824605*^9}, {3.812908820719648*^9, 3.812908909368223*^9}, 
   3.8133809253635273`*^9, {3.813402482937264*^9, 3.813402484919916*^9}, {
   3.815727989997191*^9, 3.815728003482004*^9}, {3.819644301685548*^9, 
   3.819644305685028*^9}, {3.819644418060289*^9, 3.8196444431646976`*^9}, 
   3.819644476706355*^9, {3.81964450923114*^9, 3.8196445638056383`*^9}, {
   3.8196446098161077`*^9, 3.819644616512904*^9}, 3.819644758713471*^9, {
   3.819644805886161*^9, 3.8196448188048973`*^9}, {3.819645044650301*^9, 
   3.8196450641286383`*^9}, 3.819646437998444*^9, {3.8196466447559643`*^9, 
   3.8196466485827103`*^9}, {3.819962444574202*^9, 3.8199624447437763`*^9}, {
   3.820119620567943*^9, 3.820119636432824*^9}, {3.820119774500806*^9, 
   3.820119797451242*^9}, {3.822535295408708*^9, 3.822535318649681*^9}, {
   3.823530232838211*^9, 3.823530235595704*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"517fe565-dbd4-4f72-9bce-30280a372548"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Method\"\>",
       HoldForm], 
      TagBox["\<\"Basis\"\>",
       HoldForm], 
      TagBox["\<\"1 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(3\\)]\\)\\!\\(\
\\*SubscriptBox[\\(B\\), \\(1  g\\)]\\)\"\>",
       HoldForm], 
      TagBox["\<\"1 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\
\\*SubscriptBox[\\(B\\), \\(1  g\\)]\\)\"\>",
       HoldForm], 
      TagBox["\<\"2 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\
\\*SubscriptBox[\\(A\\), \\(g\\)]\\)\"\>",
       HoldForm]},
     {"\<\"CC3\"\>", "\<\"6-31+G(d)\"\>", "1.42`", "3.341`", "4.658`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.396`", "3.158`", "4.711`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.402`", "3.119`", "4.777`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.409`", "3.113`", "4.774`"},
     {"\<\"CCSDT\"\>", "\<\"6-31+G(d)\"\>", "1.442`", "3.357`", "4.311`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.411`", "3.175`", "4.327`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.411`", "3.139`", "4.429`"},
     {"\<\"CCSDTQ\"\>", "\<\"6-31+G(d)\"\>", "\<\"\"\>", "3.34`", "4.073`"},
     {"\<\"SA2-CASSCF(4,4)\"\>", "\<\"6-31+G(d)\"\>", "1.662`", "4.657`", 
      "4.439`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.672`", "4.563`", "4.448`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.67`", "4.546`", "4.441`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.671`", "4.549`", "4.44`"},
     {"\<\"CASPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", "1.44`", "3.162`", "4.115`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.414`", "2.971`", "4.068`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.412`", "2.923`", "4.072`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.417`", "2.911`", "4.081`"},
     {"\<\"XMS-CASPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", "\<\"\"\>", "\<\"\"\>", 
      "4.151`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "\<\"\"\>", "\<\"\"\>", "4.105`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "\<\"\"\>", "\<\"\"\>", "4.114`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "\<\"\"\>", "\<\"\"\>", "4.125`"},
     {"\<\"SC-NEVPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", "1.407`", "2.707`", 
      "4.145`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.381`", "2.479`", "4.109`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.379`", "2.422`", "4.108`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.384`", "2.408`", "4.125`"},
     {"\<\"PC-NEVPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", "1.409`", "2.652`", 
      "4.12`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.384`", "2.424`", "4.084`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.382`", "2.368`", "4.083`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.387`", "2.353`", "4.091`"},
     {"\<\"MRCI(4,4)\"\>", "\<\"6-31+G(d)\"\>", "1.564`", "3.802`", 
      "4.265`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.558`", "3.67`", "4.254`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.568`", "3.678`", "4.27`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.574`", "3.681`", "4.28`"},
     {"\<\"SA2-CASSCF(12,12)\"\>", "\<\"6-31+G(d)\"\>", "1.675`", "3.924`", 
      "4.22`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.685`", "3.856`", "4.221`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.686`", "3.844`", "4.217`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.687`", "3.846`", "4.216`"},
     {"\<\"CASPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", "1.508`", "3.407`", 
      "4.099`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.489`", "3.256`", "4.044`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.48`", "3.183`", "4.043`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.482`", "3.163`", "4.047`"},
     {"\<\"XMS-CASPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", "\<\"\"\>", \
"\<\"\"\>", "4.111`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "\<\"\"\>", "\<\"\"\>", "4.056`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "\<\"\"\>", "\<\"\"\>", "4.059`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "\<\"\"\>", "\<\"\"\>", "4.065`"},
     {"\<\"SC-NEVPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", "1.522`", "3.409`", 
      "4.13`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.511`", "3.266`", "4.093`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.501`", "3.188`", "4.086`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.503`", "3.167`", "4.088`"},
     {"\<\"PC-NEVPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", "1.487`", "3.296`", 
      "4.103`"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "1.472`", "3.141`", "4.064`"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "1.462`", "3.063`", "4.056`"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "1.464`", "3.043`", "4.059`"},
     {"\<\"MRCI(12,12)\"\>", "\<\"6-31+G(d)\"\>", "\<\"\"\>", "\<\"\"\>", 
      "4.125`"},
     {"\<\"CIPSI\"\>", "\<\"6-31+G(d)\"\>", 
      InterpretationBox[
       TemplateBox[{"1.486", "0.005"},
        "Around"],
       Around[1.486, 0.005]], 
      InterpretationBox[
       TemplateBox[{"3.348", "0.024"},
        "Around"],
       Around[3.348, 0.024]], 
      InterpretationBox[
       TemplateBox[{"4.084", "0.012"},
        "Around"],
       Around[4.084, 0.012]]},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      InterpretationBox[
       TemplateBox[{"1.458", "0.009"},
        "Around"],
       Around[1.458, 0.009]], 
      InterpretationBox[
       TemplateBox[{"3.187", "0.035"},
        "Around"],
       Around[3.187, 0.035]], 
      InterpretationBox[
       TemplateBox[{"4.04", "0.04"},
        "Around"],
       Around[4.041, 0.036]]},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      InterpretationBox[
       TemplateBox[{"1.461", "0.030"},
        "Around"],
       Around[1.461, 0.03]], 
      InterpretationBox[
       TemplateBox[{"3.142", "0.035"},
        "Around"],
       Around[3.142, 0.035]], 
      InterpretationBox[
       TemplateBox[{"4.03", "0.09"},
        "Around"],
       Around[4.028, 0.086]]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Method", "Basis", 
       "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(3\)]\)\!\(\
\*SubscriptBox[\(B\), \(1  g\)]\)", 
       "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(1\)]\)\!\(\
\*SubscriptBox[\(B\), \(1  g\)]\)", 
       "2 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(1\)]\)\!\(\
\*SubscriptBox[\(A\), \(g\)]\)"}}, TableAlignments -> Left]]]], "Output",
 CellChangeTimes->{
  3.820386261119042*^9, 3.820386308590036*^9, {3.82038666589384*^9, 
   3.820386671252273*^9}, 3.8203875073095703`*^9, {3.820387663511159*^9, 
   3.8203876905027437`*^9}, {3.820388098848071*^9, 3.8203881096802692`*^9}, {
   3.820388142944037*^9, 3.8203881538252077`*^9}, 3.820393447224986*^9, 
   3.820480937985939*^9, 3.8205647208305273`*^9, 3.820564762226542*^9, 
   3.820596607948922*^9, {3.8206651190200253`*^9, 3.820665139336298*^9}, 
   3.820665184151185*^9, 3.820671514529437*^9, 3.820671789040483*^9, 
   3.820671872232398*^9, 3.820767113737714*^9, 3.820768044790141*^9, 
   3.821172902878462*^9, 3.821179211242779*^9, 3.8213763004155407`*^9, 
   3.821764309829545*^9, 3.8221497249103127`*^9, 3.822535193214501*^9, {
   3.822535299819582*^9, 3.822535320268878*^9}, 3.8226686187388277`*^9, 
   3.823530236263509*^9, 3.82482223045575*^9},
 CellLabel->
  "Out[210]//TableForm=",ExpressionUUID->"2be1012c-883f-42eb-b9e3-\
ba443f8e5e1d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spin-flip methods", "Subsubsection",
 CellChangeTimes->{{3.820894857113195*^9, 
  3.820894861987111*^9}},ExpressionUUID->"e347b647-085c-4a7a-aacb-\
16cb902d6b69"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"SetAccuracy", "[", 
    RowBox[{"CBDD2hSF", ",", "4"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Method\>\"", ",", "\"\<Basis\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(3\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)\>\"", ",", 
        "\"\<2 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(g\)]\)\>\""}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<tabSF.png\>\"", ",", "%"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8205944544976273`*^9, 3.820594459008399*^9}, {
  3.820594667795473*^9, 3.820594671489867*^9}, {3.820594881811507*^9, 
  3.8205948988448677`*^9}, {3.8221497670695972`*^9, 3.822149810405919*^9}, {
  3.822149933251874*^9, 3.822150009542362*^9}, {3.8221500902944927`*^9, 
  3.8221500949744368`*^9}, {3.8225353235908747`*^9, 3.822535352831773*^9}, {
  3.822535417812003*^9, 3.82253541841817*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"9326eaa0-341b-4e7e-b996-418c884cb254"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Method\"\>", "\<\"Basis\"\>", "\<\"1 \\!\\(\\*SuperscriptBox[\\(\
\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(A\\), \
\\(g\\)]\\)\"\>", "\<\"1 \\!\\(\\*SuperscriptBox[\\(\
\[InvisiblePrefixScriptBase]\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(B\\), \
\\(1  g\\)]\\)\"\>", "\<\"1 \\!\\(\\*SuperscriptBox[\\(\
\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(B\\), \
\\(1  g\\)]\\)\"\>", "\<\"2 \\!\\(\\*SuperscriptBox[\\(\
\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(A\\), \
\\(g\\)]\\)\"\>"},
    {"\<\"SF-CIS\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0811999999999999944`2.909556029241175"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5144999999999999574`4.180269277668875"},
       {"2.044599999999999973`4.310608356458523"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.8544000000000000483`4.585956782654268"},
       {"0.0449000000000000024`2.6522463410033232"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"5.3790000000000004476`4.730701544281845"},
       {"0.091499999999999998`2.9614210940664485"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0829000000000000015`2.918554530550274"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4872999999999998444`4.172398577939305"},
       {"2.0497000000000000774`4.311690301114878"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.7207999999999996632`4.57063632650346"},
       {"0.0548999999999999974`2.7395723444500915"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"5.348300000000000054`4.728215759975586"},
       {"0.0946000000000000035`2.975891136401793"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.085199999999999998`2.9304395947667"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4720999999999999641`4.167937312700578"},
       {"2.053700000000000081`4.312537003107304"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.7012000000000000455`4.568342553495426"},
       {"0.0575000000000000025`2.75966784468963"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"5.3421000000000002927`4.727712013419856"},
       {"0.0985000000000000042`2.993436230497612"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0855000000000000066`2.9319661147281724"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4712000000000000632`4.167671716230021"},
       {"2.0541000000000000369`4.312621582586981"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.7015000000000002345`4.568377753718221"},
       {"0.0579000000000000001`2.762678563727436"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"5.3422999999999998266`4.72772827243232"},
       {"0.1000999999999999945`3.000434077479319"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-B3LYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0103000000000000001`2.012837224705172"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.706100000000000172`4.23200448297183"},
       {"1.9900999999999999801`4.298874899704699"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.2107999999999998764`4.344549455909737"},
       {"0.0271999999999999985`2.4345689040341987"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.9931000000000000938`4.601310186453887"},
       {"0.0166000000000000002`2.220108088040055"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0102000000000000007`2.0086001717619175"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.705600000000000005`4.231877187346478"},
       {"1.9896000000000000352`4.29876577226188"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.2038000000000002032`4.3431721787289375"},
       {"0.0281`2.44870631990508"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.9924999999999997158`4.60124492481052"},
       {"0.0161999999999999991`2.2095150145426308"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0108000000000000006`2.03342375548695"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7027000000000001023`4.2311381360297196"},
       {"1.9890000000000001013`4.298634783124435"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.1989000000000000767`4.342205479276342"},
       {"0.0298999999999999995`2.475671188324429"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.9879999999999999893`4.600755149639618"},
       {"0.016799999999999999`2.225309281725863"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0108000000000000006`2.03342375548695"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7031000000000000583`4.2312401489450755"},
       {"1.9891000000000000902`4.298656617391146"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.1993999999999997996`4.342304220718211"},
       {"0.0298999999999999995`2.475671188324429"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.9887999999999999012`4.600842261159698"},
       {"0.0168999999999999984`2.2278867046136734"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-PBE0\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0114999999999999998`2.060697840353612"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6869000000000000661`4.2270893382290655"},
       {"2.0017999999999998018`4.301420684913891"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3138000000000000789`4.364325816737502"},
       {"0.0172999999999999994`2.238046103128795"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.089199999999999946`4.611638352122505"},
       {"0.0178999999999999992`2.252853030979893"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0117999999999999997`2.0718820073061255"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6843999999999998973`4.226445232748228"},
       {"2.0013999999999998458`4.301333895448794"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3011999999999996902`4.361954365353462"},
       {"0.0190999999999999989`2.281033367247727"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.0849000000000001975`4.611181429294439"},
       {"0.0181000000000000015`2.2576785748691846"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0126000000000000001`2.100370545117563"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6817999999999999616`4.22577434814393"},
       {"2.0013000000000000789`4.301312195372246"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.2960000000000002629`4.360971883725936"},
       {"0.0208999999999999984`2.320146286111054"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.081400000000000361`4.610809160144461"},
       {"0.0190999999999999989`2.281033367247727"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0126999999999999995`2.103803720955957"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6817999999999999616`4.22577434814393"},
       {"2.0015000000000000568`4.301355594441124"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.2961999999999997968`4.361009712608142"},
       {"0.0208999999999999984`2.320146286111054"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.0788000000000002032`4.610532410630684"},
       {"0.0191999999999999983`2.2833012287035492"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-BHHLYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0275999999999999995`2.4409090820652177"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5520999999999998131`4.190919698912573"},
       {"2.0150000000000001243`4.304275050477128"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7790999999999996817`4.443904174221353"},
       {"0.0224999999999999992`2.3521825181113623"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.4283000000000001251`4.646237034955377"},
       {"0.0400999999999999968`2.603144372620182"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0277999999999999983`2.444044795918076"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5464999999999999858`4.189349924339198"},
       {"2.0160999999999997812`4.304512069624235"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7435000000000000497`4.438304964532098"},
       {"0.0245000000000000009`2.3891660843645326"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.4216999999999995197`4.645589273574147"},
       {"0.0400999999999999968`2.603144372620182"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.028500000000000001`2.45484486000851"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5402000000000000135`4.187577119055087"},
       {"2.017199999999999882`4.304748959487095"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7317000000000000171`4.436433002660097"},
       {"0.0256000000000000012`2.4082399653118496"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.4924999999999997158`4.652488085781012"},
       {"0.0410000000000000017`2.6127838567197355"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0286000000000000004`2.456366033129043"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5400000000000000355`4.187520720836463"},
       {"2.0173000000000000931`4.304770488523259"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7321999999999997399`4.436512486999693"},
       {"0.0257000000000000006`2.409933123331294"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.4149000000000002686`4.644920871007577"},
       {"0.0412000000000000005`2.614897216033134"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-M06-2X\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0281`2.44870631990508"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4771000000000000796`4.169409898140701"},
       {"2.0114999999999998437`4.303520036907281"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.8351999999999999424`4.452583700206957"},
       {"0.0134999999999999998`2.130333768495006"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3780999999999998806`4.641285677047399"},
       {"0.0388000000000000012`2.5888317255942073"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0281999999999999994`2.4502491083193614"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4669000000000000927`4.166400508575069"},
       {"2.0129000000000001336`4.303822199862847"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7846999999999999531`4.444778414819479"},
       {"0.0155999999999999993`2.1931245983544616"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3596000000000003638`4.63944664391034"},
       {"0.0386999999999999983`2.587710965018911"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0287999999999999992`2.459392487759231"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4616999999999999993`4.164858246962555"},
       {"2.0139999999999997904`4.304059466217599"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7709000000000001407`4.442620852656338"},
       {"0.0173999999999999988`2.2405492482826"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3570000000000002061`4.6391875599357535"},
       {"0.0396000000000000033`2.597695185925512"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0287999999999999992`2.459392487759231"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4582000000000001627`4.1638170938993255"},
       {"2.0137999999999998124`4.304016336520767"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7705999999999999517`4.442573829884634"},
       {"0.0172999999999999994`2.238046103128795"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3521000000000000796`4.638698865768533"},
       {"0.0396999999999999992`2.598790506763115"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-CAM-B3LYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0137999999999999998`2.1398790864012365"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.749900000000000011`4.2430132311496775"},
       {"1.9895000000000000462`4.298743943482407"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3365000000000000213`4.368565785360332"},
       {"0.0292000000000000003`2.465382851448418"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.3147999999999999687`4.520457330171663"},
       {"0.0166000000000000002`2.220108088040055"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0140000000000000003`2.1461280356782377"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7446999999999999176`4.241720761068594"},
       {"1.9900999999999999801`4.298874899704699"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3227000000000002089`4.365993119934445"},
       {"0.0309999999999999998`2.4913616938342726"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1402999999999998693`4.6170318105953445"},
       {"0.0229999999999999996`2.361727836017593"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0145000000000000007`2.161368002234975"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7424999999999999378`4.241172786770047"},
       {"1.9899000000000000021`4.298831252018038"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3182000000000000384`4.365150901493603"},
       {"0.032599999999999997`2.513217600067939"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1379000000000001336`4.6167799909278395"},
       {"0.0235000000000000001`2.3710678622717363"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0146000000000000001`2.164352855784437"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7425999999999999268`4.2411977096980555"},
       {"1.9899000000000000021`4.298831252018038"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3185000000000002274`4.365207100231824"},
       {"0.0326999999999999999`2.5145477526602864"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1383000000000000895`4.616821971013604"},
       {"0.0235999999999999995`2.3729120029701067"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-\[Omega]B97X-V\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0134000000000000005`2.1271047983648077"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.8104999999999999982`4.257798529153031"},
       {"1.9871000000000000885`4.298219723353091"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3768000000000002458`4.375992638795608"},
       {"0.0281`2.44870631990508"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2198999999999999844`4.625302159501302"},
       {"0.0223999999999999998`2.3502480183341627"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0142000000000000008`2.1522883443830563"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7998000000000000664`4.255224247479844"},
       {"1.9867999999999998995`4.298154151323185"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3559000000000001052`4.372156852171986"},
       {"0.0328000000000000028`2.5158738437116788"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2165999999999996817`4.624962404421975"},
       {"0.0234000000000000007`2.369215857410143"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0146000000000000001`2.164352855784437"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7967999999999999527`4.254499738917382"},
       {"1.9863999999999999435`4.298066706546508"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.3510999999999997456`4.371271101487585"},
       {"0.0345999999999999988`2.5390760987927763"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2127999999999996561`4.624570841761993"},
       {"0.0239000000000000011`2.3783979009481375"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-M11\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0246999999999999997`2.392696953259666"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5663000000000000256`4.194874947930378"},
       {"2.0081999999999999851`4.30280696274142"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.686799999999999855`4.429235339626655"},
       {"0.0184999999999999991`2.2671717284030137"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2919000000000000483`4.6326495944788775"},
       {"0.0415999999999999981`2.6190933306267423"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0252000000000000002`2.401400540781544"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5457999999999998408`4.1891533029618895"},
       {"2.0104000000000001869`4.30328247558452"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.6399999999999996803`4.421603926869831"},
       {"0.0227000000000000014`2.3560258571931225"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.267199999999999882`4.630142998345801"},
       {"0.0435999999999999999`2.639486489268586"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0254999999999999984`2.406540180433955"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5590999999999999304`4.192873971542522"},
       {"2.0112000000000000988`4.303455260341883"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.650999999999999801`4.423409727733094"},
       {"0.023099999999999999`2.3636119798921444"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3001000000000004775`4.63347855533382"},
       {"0.0446999999999999967`2.650307523131936"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0254999999999999984`2.406540180433955"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5571999999999999176`4.192344395046124"},
       {"2.0114000000000000767`4.3034984457923136"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.6501000000000001222`4.423262262098614"},
       {"0.0219999999999999987`2.342422680822206"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2986000000000004206`4.633327034352867"},
       {"0.043499999999999997`2.638489256954637"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-LC-\[Omega]PBE08\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0164000000000000014`2.214843848047698"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.9173000000000000043`4.282690072268219"},
       {"1.9831000000000000849`4.297344614534694"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.4451999999999998181`4.388314387117743"},
       {"0.0347000000000000017`2.5403294747908736"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3528000000000002245`4.638768712897848"},
       {"0.0282999999999999988`2.4517864355242898"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0179999999999999986`2.255272505103306"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.8970000000000002416`4.278067330888663"},
       {"1.9847999999999998977`4.2977167512641525"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.4146999999999998465`4.382863182111264"},
       {"0.0415999999999999981`2.6190933306267423"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3455000000000003624`4.638039754259443"},
       {"0.0303999999999999999`2.482873583608754"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0189000000000000001`2.276461804173244"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.8967000000000000526`4.277998644200288"},
       {"1.9842999999999999527`4.29760733238224"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.4145000000000003126`4.382827209736366"},
       {"0.0442999999999999991`2.6464037262230695"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3479000000000000981`4.638279546925845"},
       {"0.0311999999999999986`2.494154594018443"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0189000000000000001`2.276461804173244"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.8966000000000000636`4.277975746223223"},
       {"1.9845999999999999197`4.297672987019454"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.4145000000000003126`4.382827209736366"},
       {"0.0442000000000000032`2.6454222693490914"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.3477999999999994429`4.638269558207699"},
       {"0.0313000000000000014`2.4955443375464483"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-B2PLYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0307000000000000016`2.4871383754771865"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5375000000000000888`4.186815124447454"},
       {"2.0173000000000000931`4.304770488523259"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.8269999999999999574`4.4513258084895195"},
       {"0.0246999999999999997`2.392696953259666"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.4619999999999997442`4.649529565947819"},
       {"0.0441000000000000003`2.644438589467838"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0309000000000000004`2.4899584794248346"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5312999999999998835`4.185060282521392"},
       {"2.0186999999999999389`4.305071783022292"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7880000000000002558`4.445292769425972"},
       {"0.0270999999999999991`2.432969290874406"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.455400000000000027`4.648886700515307"},
       {"0.0442999999999999991`2.6464037262230695"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0318000000000000019`2.5024271199844326"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5245999999999999552`4.183155915434013"},
       {"2.0200000000000000178`4.305351369446623"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7759000000000000341`4.443403816887126"},
       {"0.0284000000000000016`2.4533183400470375"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.4481999999999999318`4.648184305764576"},
       {"0.0454000000000000029`2.6570558528571038"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-ADC(2)-s\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5774080000000001434`4.197944039068329"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.30336799999999986`4.518956957423446"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1962360000000007432`4.622859905311681"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5127759999999998985`4.179774625864584"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.116163999999999934`4.493620306003343"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1138700000000003598`4.614250563689602"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5306519999999999015`4.184876463292042"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.0986650000000000027`4.491174626734403"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1307139999999993307`4.616025126585965"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5438300000000000356`4.188599475969471"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.1005599999999997607`4.4914401399457615"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.1402299999999998548`4.617024467921933"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-ADC(2)-x\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5574530000000001984`4.192414949617798"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.2320130000000002468`4.50947309895184"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.7275439999999999685`4.571422778575582"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5238719999999998933`4.18294848929473"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.0392369999999999663`4.482764567726849"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.6805950000000002831`4.565918031806368"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5393840000000000856`4.187346968290876"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.0313080000000001135`4.481630065666411"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.7033540000000000347`4.568595227820012"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-ADC(3)\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4349000000000000643`4.156821635591626"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.3515030000000001209`4.525239612475937"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2423130000000002227`4.627602707829309"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4218340000000000423`4.15284889520368"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.1796060000000001544`4.502373307837551"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2080610000000007176`4.62408202671873"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4188459999999998296`4.151935260165229"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.1619320000000001869`4.499952525829485"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2235059999999995384`4.625673115486828"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-EOM-CCSD\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6628000000000000558`4.2208400158341774"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.5152000000000001023`4.545950039576435"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2754000000000003112`4.630976752904219"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6106000000000000316`4.206987694756409"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.3147000000000002018`4.520444228294238"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.8559999999999998721`4.586137025230793"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6090999999999999748`4.2065830348377915"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.2930000000000001492`4.517591730711908"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.2450000000000001066`4.627877694579971"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-EOM-CC(2,3)\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4904999999999999361`4.1733319803686495"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.3326999999999999957`4.522796221488767"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.0606999999999997542`4.608600905481854"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.463999999999999968`4.1655410767223735"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.1561000000000003496`4.499150755234519"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"4.0270999999999999019`4.6049924140397565"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]}
   },
   GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  TableForm[{{
    "SF-CIS", "6-31+G(d)", {0``4., 0.0811999999999999944`2.909556029241175}, {
     1.5144999999999999574`4.180269277668875, 
      2.044599999999999973`4.310608356458523}, {
     3.8544000000000000483`4.585956782654268, 
      0.0449000000000000024`2.6522463410033232}, {
     5.3790000000000004476`4.730701544281845, 
      0.091499999999999998`2.9614210940664485}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0829000000000000015`2.918554530550274}, {
     1.4872999999999998444`4.172398577939305, 
      2.0497000000000000774`4.311690301114878}, {
     3.7207999999999996632`4.57063632650346, 
      0.0548999999999999974`2.7395723444500915}, {
     5.348300000000000054`4.728215759975586, 
      0.0946000000000000035`2.975891136401793}}, {
    "", "aug-cc-pVTZ", {0``4., 0.085199999999999998`2.9304395947667}, {
     1.4720999999999999641`4.167937312700578, 
      2.053700000000000081`4.312537003107304}, {
     3.7012000000000000455`4.568342553495426, 
      0.0575000000000000025`2.75966784468963}, {
     5.3421000000000002927`4.727712013419856, 
      0.0985000000000000042`2.993436230497612}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0855000000000000066`2.9319661147281724}, {
     1.4712000000000000632`4.167671716230021, 
      2.0541000000000000369`4.312621582586981}, {
     3.7015000000000002345`4.568377753718221, 
      0.0579000000000000001`2.762678563727436}, {
     5.3422999999999998266`4.72772827243232, 
      0.1000999999999999945`3.000434077479319}}, {
    "SF-TD-B3LYP", "6-31+G(d)", {
     0``4., 0.0103000000000000001`2.012837224705172}, {
     1.706100000000000172`4.23200448297183, 
      1.9900999999999999801`4.298874899704699}, {
     2.2107999999999998764`4.344549455909737, 
      0.0271999999999999985`2.4345689040341987}, {
     3.9931000000000000938`4.601310186453887, 
      0.0166000000000000002`2.220108088040055}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0102000000000000007`2.0086001717619175}, {
     1.705600000000000005`4.231877187346478, 
      1.9896000000000000352`4.29876577226188}, {
     2.2038000000000002032`4.3431721787289375, 0.0281`2.44870631990508}, {
     3.9924999999999997158`4.60124492481052, 
      0.0161999999999999991`2.2095150145426308}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0108000000000000006`2.03342375548695}, {
     1.7027000000000001023`4.2311381360297196, 
      1.9890000000000001013`4.298634783124435}, {
     2.1989000000000000767`4.342205479276342, 
      0.0298999999999999995`2.475671188324429}, {
     3.9879999999999999893`4.600755149639618, 
      0.016799999999999999`2.225309281725863}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0108000000000000006`2.03342375548695}, {
     1.7031000000000000583`4.2312401489450755, 
      1.9891000000000000902`4.298656617391146}, {
     2.1993999999999997996`4.342304220718211, 
      0.0298999999999999995`2.475671188324429}, {
     3.9887999999999999012`4.600842261159698, 
      0.0168999999999999984`2.2278867046136734}}, {
    "SF-TD-PBE0", "6-31+G(d)", {
     0``4., 0.0114999999999999998`2.060697840353612}, {
     1.6869000000000000661`4.2270893382290655, 
      2.0017999999999998018`4.301420684913891}, {
     2.3138000000000000789`4.364325816737502, 
      0.0172999999999999994`2.238046103128795}, {
     4.089199999999999946`4.611638352122505, 
      0.0178999999999999992`2.252853030979893}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0117999999999999997`2.0718820073061255}, {
     1.6843999999999998973`4.226445232748228, 
      2.0013999999999998458`4.301333895448794}, {
     2.3011999999999996902`4.361954365353462, 
      0.0190999999999999989`2.281033367247727}, {
     4.0849000000000001975`4.611181429294439, 
      0.0181000000000000015`2.2576785748691846}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0126000000000000001`2.100370545117563}, {
     1.6817999999999999616`4.22577434814393, 
      2.0013000000000000789`4.301312195372246}, {
     2.2960000000000002629`4.360971883725936, 
      0.0208999999999999984`2.320146286111054}, {
     4.081400000000000361`4.610809160144461, 
      0.0190999999999999989`2.281033367247727}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0126999999999999995`2.103803720955957}, {
     1.6817999999999999616`4.22577434814393, 
      2.0015000000000000568`4.301355594441124}, {
     2.2961999999999997968`4.361009712608142, 
      0.0208999999999999984`2.320146286111054}, {
     4.0788000000000002032`4.610532410630684, 
      0.0191999999999999983`2.2833012287035492}}, {
    "SF-TD-BHHLYP", "6-31+G(d)", {
     0``4., 0.0275999999999999995`2.4409090820652177}, {
     1.5520999999999998131`4.190919698912573, 
      2.0150000000000001243`4.304275050477128}, {
     2.7790999999999996817`4.443904174221353, 
      0.0224999999999999992`2.3521825181113623}, {
     4.4283000000000001251`4.646237034955377, 
      0.0400999999999999968`2.603144372620182}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0277999999999999983`2.444044795918076}, {
     1.5464999999999999858`4.189349924339198, 
      2.0160999999999997812`4.304512069624235}, {
     2.7435000000000000497`4.438304964532098, 
      0.0245000000000000009`2.3891660843645326}, {
     4.4216999999999995197`4.645589273574147, 
      0.0400999999999999968`2.603144372620182}}, {
    "", "aug-cc-pVTZ", {0``4., 0.028500000000000001`2.45484486000851}, {
     1.5402000000000000135`4.187577119055087, 
      2.017199999999999882`4.304748959487095}, {
     2.7317000000000000171`4.436433002660097, 
      0.0256000000000000012`2.4082399653118496}, {
     4.4924999999999997158`4.652488085781012, 
      0.0410000000000000017`2.6127838567197355}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0286000000000000004`2.456366033129043}, {
     1.5400000000000000355`4.187520720836463, 
      2.0173000000000000931`4.304770488523259}, {
     2.7321999999999997399`4.436512486999693, 
      0.0257000000000000006`2.409933123331294}, {
     4.4149000000000002686`4.644920871007577, 
      0.0412000000000000005`2.614897216033134}}, {
    "SF-TD-M06-2X", "6-31+G(d)", {0``4., 0.0281`2.44870631990508}, {
     1.4771000000000000796`4.169409898140701, 
      2.0114999999999998437`4.303520036907281}, {
     2.8351999999999999424`4.452583700206957, 
      0.0134999999999999998`2.130333768495006}, {
     4.3780999999999998806`4.641285677047399, 
      0.0388000000000000012`2.5888317255942073}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0281999999999999994`2.4502491083193614}, {
     1.4669000000000000927`4.166400508575069, 
      2.0129000000000001336`4.303822199862847}, {
     2.7846999999999999531`4.444778414819479, 
      0.0155999999999999993`2.1931245983544616}, {
     4.3596000000000003638`4.63944664391034, 
      0.0386999999999999983`2.587710965018911}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0287999999999999992`2.459392487759231}, {
     1.4616999999999999993`4.164858246962555, 
      2.0139999999999997904`4.304059466217599}, {
     2.7709000000000001407`4.442620852656338, 
      0.0173999999999999988`2.2405492482826}, {
     4.3570000000000002061`4.6391875599357535, 
      0.0396000000000000033`2.597695185925512}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0287999999999999992`2.459392487759231}, {
     1.4582000000000001627`4.1638170938993255, 
      2.0137999999999998124`4.304016336520767}, {
     2.7705999999999999517`4.442573829884634, 
      0.0172999999999999994`2.238046103128795}, {
     4.3521000000000000796`4.638698865768533, 
      0.0396999999999999992`2.598790506763115}}, {
    "SF-TD-CAM-B3LYP", "6-31+G(d)", {
     0``4., 0.0137999999999999998`2.1398790864012365}, {
     1.749900000000000011`4.2430132311496775, 
      1.9895000000000000462`4.298743943482407}, {
     2.3365000000000000213`4.368565785360332, 
      0.0292000000000000003`2.465382851448418}, {
     3.3147999999999999687`4.520457330171663, 
      0.0166000000000000002`2.220108088040055}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0140000000000000003`2.1461280356782377}, {
     1.7446999999999999176`4.241720761068594, 
      1.9900999999999999801`4.298874899704699}, {
     2.3227000000000002089`4.365993119934445, 
      0.0309999999999999998`2.4913616938342726}, {
     4.1402999999999998693`4.6170318105953445, 
      0.0229999999999999996`2.361727836017593}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0145000000000000007`2.161368002234975}, {
     1.7424999999999999378`4.241172786770047, 
      1.9899000000000000021`4.298831252018038}, {
     2.3182000000000000384`4.365150901493603, 
      0.032599999999999997`2.513217600067939}, {
     4.1379000000000001336`4.6167799909278395, 
      0.0235000000000000001`2.3710678622717363}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0146000000000000001`2.164352855784437}, {
     1.7425999999999999268`4.2411977096980555, 
      1.9899000000000000021`4.298831252018038}, {
     2.3185000000000002274`4.365207100231824, 
      0.0326999999999999999`2.5145477526602864}, {
     4.1383000000000000895`4.616821971013604, 
      0.0235999999999999995`2.3729120029701067}}, {
    "SF-TD-\[Omega]B97X-V", "6-31+G(d)", {
     0``4., 0.0134000000000000005`2.1271047983648077}, {
     1.8104999999999999982`4.257798529153031, 
      1.9871000000000000885`4.298219723353091}, {
     2.3768000000000002458`4.375992638795608, 0.0281`2.44870631990508}, {
     4.2198999999999999844`4.625302159501302, 
      0.0223999999999999998`2.3502480183341627}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0142000000000000008`2.1522883443830563}, {
     1.7998000000000000664`4.255224247479844, 
      1.9867999999999998995`4.298154151323185}, {
     2.3559000000000001052`4.372156852171986, 
      0.0328000000000000028`2.5158738437116788}, {
     4.2165999999999996817`4.624962404421975, 
      0.0234000000000000007`2.369215857410143}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0146000000000000001`2.164352855784437}, {
     1.7967999999999999527`4.254499738917382, 
      1.9863999999999999435`4.298066706546508}, {
     2.3510999999999997456`4.371271101487585, 
      0.0345999999999999988`2.5390760987927763}, {
     4.2127999999999996561`4.624570841761993, 
      0.0239000000000000011`2.3783979009481375}}, {
    "SF-TD-M11", "6-31+G(d)", {
     0``4., 0.0246999999999999997`2.392696953259666}, {
     1.5663000000000000256`4.194874947930378, 
      2.0081999999999999851`4.30280696274142}, {
     2.686799999999999855`4.429235339626655, 
      0.0184999999999999991`2.2671717284030137}, {
     4.2919000000000000483`4.6326495944788775, 
      0.0415999999999999981`2.6190933306267423}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0252000000000000002`2.401400540781544}, {
     1.5457999999999998408`4.1891533029618895, 
      2.0104000000000001869`4.30328247558452}, {
     2.6399999999999996803`4.421603926869831, 
      0.0227000000000000014`2.3560258571931225}, {
     4.267199999999999882`4.630142998345801, 
      0.0435999999999999999`2.639486489268586}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0254999999999999984`2.406540180433955}, {
     1.5590999999999999304`4.192873971542522, 
      2.0112000000000000988`4.303455260341883}, {
     2.650999999999999801`4.423409727733094, 
      0.023099999999999999`2.3636119798921444}, {
     4.3001000000000004775`4.63347855533382, 
      0.0446999999999999967`2.650307523131936}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0254999999999999984`2.406540180433955}, {
     1.5571999999999999176`4.192344395046124, 
      2.0114000000000000767`4.3034984457923136}, {
     2.6501000000000001222`4.423262262098614, 
      0.0219999999999999987`2.342422680822206}, {
     4.2986000000000004206`4.633327034352867, 
      0.043499999999999997`2.638489256954637}}, {
    "SF-TD-LC-\[Omega]PBE08", "6-31+G(d)", {
     0``4., 0.0164000000000000014`2.214843848047698}, {
     1.9173000000000000043`4.282690072268219, 
      1.9831000000000000849`4.297344614534694}, {
     2.4451999999999998181`4.388314387117743, 
      0.0347000000000000017`2.5403294747908736}, {
     4.3528000000000002245`4.638768712897848, 
      0.0282999999999999988`2.4517864355242898}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0179999999999999986`2.255272505103306}, {
     1.8970000000000002416`4.278067330888663, 
      1.9847999999999998977`4.2977167512641525}, {
     2.4146999999999998465`4.382863182111264, 
      0.0415999999999999981`2.6190933306267423}, {
     4.3455000000000003624`4.638039754259443, 
      0.0303999999999999999`2.482873583608754}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0189000000000000001`2.276461804173244}, {
     1.8967000000000000526`4.277998644200288, 
      1.9842999999999999527`4.29760733238224}, {
     2.4145000000000003126`4.382827209736366, 
      0.0442999999999999991`2.6464037262230695}, {
     4.3479000000000000981`4.638279546925845, 
      0.0311999999999999986`2.494154594018443}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0189000000000000001`2.276461804173244}, {
     1.8966000000000000636`4.277975746223223, 
      1.9845999999999999197`4.297672987019454}, {
     2.4145000000000003126`4.382827209736366, 
      0.0442000000000000032`2.6454222693490914}, {
     4.3477999999999994429`4.638269558207699, 
      0.0313000000000000014`2.4955443375464483}}, {
    "SF-TD-B2PLYP", "6-31+G(d)", {
     0``4., 0.0307000000000000016`2.4871383754771865}, {
     1.5375000000000000888`4.186815124447454, 
      2.0173000000000000931`4.304770488523259}, {
     2.8269999999999999574`4.4513258084895195, 
      0.0246999999999999997`2.392696953259666}, {
     4.4619999999999997442`4.649529565947819, 
      0.0441000000000000003`2.644438589467838}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0309000000000000004`2.4899584794248346}, {
     1.5312999999999998835`4.185060282521392, 
      2.0186999999999999389`4.305071783022292}, {
     2.7880000000000002558`4.445292769425972, 
      0.0270999999999999991`2.432969290874406}, {
     4.455400000000000027`4.648886700515307, 
      0.0442999999999999991`2.6464037262230695}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0318000000000000019`2.5024271199844326}, {
     1.5245999999999999552`4.183155915434013, 
      2.0200000000000000178`4.305351369446623}, {
     2.7759000000000000341`4.443403816887126, 
      0.0284000000000000016`2.4533183400470375}, {
     4.4481999999999999318`4.648184305764576, 
      0.0454000000000000029`2.6570558528571038}}, {
    "SF-ADC(2)-s", "6-31+G(d)", {0``4., ""}, {
     1.5774080000000001434`4.197944039068329, ""}, {
     3.30336799999999986`4.518956957423446, ""}, {
     4.1962360000000007432`4.622859905311681, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     1.5127759999999998985`4.179774625864584, ""}, {
     3.116163999999999934`4.493620306003343, ""}, {
     4.1138700000000003598`4.614250563689602, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     1.5306519999999999015`4.184876463292042, ""}, {
     3.0986650000000000027`4.491174626734403, ""}, {
     4.1307139999999993307`4.616025126585965, ""}}, {
    "", "aug-cc-pVQZ", {0``4., ""}, {
     1.5438300000000000356`4.188599475969471, ""}, {
     3.1005599999999997607`4.4914401399457615, ""}, {
     4.1402299999999998548`4.617024467921933, ""}}, {
    "SF-ADC(2)-x", "6-31+G(d)", {0``4., ""}, {
     1.5574530000000001984`4.192414949617798, ""}, {
     3.2320130000000002468`4.50947309895184, ""}, {
     3.7275439999999999685`4.571422778575582, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     1.5238719999999998933`4.18294848929473, ""}, {
     3.0392369999999999663`4.482764567726849, ""}, {
     3.6805950000000002831`4.565918031806368, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     1.5393840000000000856`4.187346968290876, ""}, {
     3.0313080000000001135`4.481630065666411, ""}, {
     3.7033540000000000347`4.568595227820012, ""}}, {
    "SF-ADC(3)", "6-31+G(d)", {0``4., ""}, {
     1.4349000000000000643`4.156821635591626, ""}, {
     3.3515030000000001209`4.525239612475937, ""}, {
     4.2423130000000002227`4.627602707829309, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     1.4218340000000000423`4.15284889520368, ""}, {
     3.1796060000000001544`4.502373307837551, ""}, {
     4.2080610000000007176`4.62408202671873, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     1.4188459999999998296`4.151935260165229, ""}, {
     3.1619320000000001869`4.499952525829485, ""}, {
     4.2235059999999995384`4.625673115486828, ""}}, {
    "SF-EOM-CCSD", "6-31+G(d)", {0``4., ""}, {
     1.6628000000000000558`4.2208400158341774, ""}, {
     3.5152000000000001023`4.545950039576435, ""}, {
     4.2754000000000003112`4.630976752904219, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     1.6106000000000000316`4.206987694756409, ""}, {
     3.3147000000000002018`4.520444228294238, ""}, {
     3.8559999999999998721`4.586137025230793, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     1.6090999999999999748`4.2065830348377915, ""}, {
     3.2930000000000001492`4.517591730711908, ""}, {
     4.2450000000000001066`4.627877694579971, ""}}, {
    "SF-EOM-CC(2,3)", "6-31+G(d)", {0``4., ""}, {
     1.4904999999999999361`4.1733319803686495, ""}, {
     3.3326999999999999957`4.522796221488767, ""}, {
     4.0606999999999997542`4.608600905481854, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     1.463999999999999968`4.1655410767223735, ""}, {
     3.1561000000000003496`4.499150755234519, ""}, {
     4.0270999999999999019`4.6049924140397565, ""}}}, 
   TableHeadings -> {
    None, {"Method", "Basis", 
      "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(g\)]\)", 
      "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(3\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)", 
      "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)", 
      "2 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(g\)]\)"}}, TableAlignments -> 
   Left]]], "Output",
 CellChangeTimes->{
  3.820594459378104*^9, {3.820594664055993*^9, 3.820594702507551*^9}, {
   3.820594745744074*^9, 3.820594809777307*^9}, {3.8205948878054132`*^9, 
   3.820594899411694*^9}, 3.820594942424707*^9, 3.820595003066334*^9, 
   3.820595227795158*^9, 3.8205965994652233`*^9, {3.8206717905957947`*^9, 
   3.820671800550408*^9}, 3.82067187567984*^9, {3.8207671168777313`*^9, 
   3.820767127170104*^9}, 3.820767631786058*^9, 3.821172903765006*^9, 
   3.8211791508106623`*^9, 3.8213763022293053`*^9, {3.821764094050694*^9, 
   3.8217641223298273`*^9}, 3.8217642840661592`*^9, 3.8221497322658367`*^9, {
   3.822149785975292*^9, 3.822149815260906*^9}, {3.822149941715822*^9, 
   3.822150010281708*^9}, 3.822150095342737*^9, 3.8225352700920773`*^9, {
   3.822535324153667*^9, 3.822535353289237*^9}, 3.8225354203926888`*^9, 
   3.823670777217478*^9, 3.823702879765024*^9, 3.824822230559915*^9},
 CellLabel->
  "Out[211]//TableForm=",ExpressionUUID->"97c1e6af-851b-4074-9392-\
0292b07355a3"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graph", "Subsection",
 CellChangeTimes->{{3.81572801260189*^9, 
  3.815728013465206*^9}},ExpressionUUID->"a0eea47c-0908-49f4-87f8-\
8a7d458525f2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalDelta]\[CapitalEpsilon]", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CBDD2h", "\[LeftDoubleBracket]", 
      RowBox[{";;", ",", "k"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "2", ",", "12"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"state", "=", 
   RowBox[{"CBDD2h", "\[LeftDoubleBracket]", 
    RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"method", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<SF-TDB3LYP\>\"", ",", "\"\<SF-TDBH\\\\&HLYP\>\"", ",", 
     "\"\<SF-CIS\>\"", ",", "\"\<SF-BSE@G$_0$W$_0$\>\"", ",", 
     "\"\<SF-dBSE@G$_0$W$_0$\>\"", ",", "\"\<SF-ADC(2)-s\>\"", ",", 
     "\"\<SF-ADC(2)-x\>\"", ",", "\"\<SF-ADC(3)\>\"", ",", 
     "\"\<EOM-SF-CCSD\>\"", ",", "\"\<EOM-SF-CCSD(fT)\>\"", ",", 
     "\"\<EOM-SF-CCSD(dT)\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"color", "=", 
   RowBox[{"{", 
    RowBox[{
    "Red", ",", "Red", ",", "Red", ",", "Purple", ",", "Blue", ",", "Blue", 
     ",", "Orange", ",", "Orange", ",", "Orange", ",", "Black", ",", "Black", 
     ",", "Black"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.815391447263088*^9, 3.8153915583696947`*^9}, {
   3.815391622062799*^9, 3.81539162625043*^9}, {3.815392844211356*^9, 
   3.8153928836939*^9}, {3.815393092258647*^9, 3.815393132674279*^9}, {
   3.8153932602305183`*^9, 3.8153933247257767`*^9}, {3.8154594299471607`*^9, 
   3.8154594302816877`*^9}, {3.815728026630252*^9, 3.815728031199445*^9}, {
   3.815728070833392*^9, 3.815728093160161*^9}, {3.8157286887990932`*^9, 
   3.815728768663549*^9}, {3.815728907226475*^9, 3.81572894011137*^9}, {
   3.815729044043872*^9, 3.815729059412303*^9}, {3.815733786078485*^9, 
   3.815733821629839*^9}, {3.815733882176507*^9, 3.81573389979125*^9}, {
   3.815733956242939*^9, 3.815733961956698*^9}, {3.815733995030712*^9, 
   3.8157340525515537`*^9}, {3.8157340952998457`*^9, 
   3.8157340990147743`*^9}, {3.815734471521256*^9, 3.815734585494651*^9}, 
   3.8193013337044153`*^9, {3.8193013637649393`*^9, 3.8193013747334623`*^9}, {
   3.8193015162097063`*^9, 3.819301539437615*^9}, {3.819301574519876*^9, 
   3.8193015752886*^9}, {3.81930176645378*^9, 3.819301766832263*^9}, {
   3.819301892054942*^9, 3.81930191937278*^9}, {3.8193430141656322`*^9, 
   3.819343017404599*^9}, {3.819642275871406*^9, 3.81964227733181*^9}, {
   3.8196423436470823`*^9, 3.819642393755364*^9}, {3.819646550430759*^9, 
   3.819646591460052*^9}, {3.819646627951923*^9, 3.8196466795537367`*^9}, {
   3.8196467383058643`*^9, 3.8196467434906883`*^9}, {3.819962447880218*^9, 
   3.819962452835278*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"c94fe3f6-bb2b-425b-9436-cceb389f4f54"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Callout", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"2", "m"}], "-", 
                RowBox[{"3", "/", "2"}]}], ",", 
               RowBox[{
               "\[CapitalDelta]\[CapitalEpsilon]", "\[LeftDoubleBracket]", 
                RowBox[{"m", ",", "k"}], "\[RightDoubleBracket]"}]}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", 
               RowBox[{
               "Length", "[", "\[CapitalDelta]\[CapitalEpsilon]", "]"}]}], 
              "}"}]}], "]"}], ",", 
           RowBox[{
           "state", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"LightGreen", ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"LightOrange", ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"LightRed", ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"LightPurple", ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], "}"}]}]}], 
      "]"}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"2", "m"}], "-", "2"}], "\[LessEqual]", "x", 
             "\[LessEqual]", 
             RowBox[{
              RowBox[{"2", "m"}], "-", "1"}]}], ",", 
            RowBox[{
            "\[CapitalDelta]\[CapitalEpsilon]", "\[LeftDoubleBracket]", "m", 
             "\[RightDoubleBracket]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{
              "Length", "[", "\[CapitalDelta]\[CapitalEpsilon]", "]"}]}], "-",
              "1"}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Thick", ",", 
             RowBox[{
             "color", "\[LeftDoubleBracket]", "m", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", 
          RowBox[{"Length", "[", "\[CapitalDelta]\[CapitalEpsilon]", "]"}]}], 
         "}"}]}], "]"}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"MaTeX", "[", 
     RowBox[{"\"\<\\\\text{CBD (D$_{2h}$)}\>\"", ",", 
      RowBox[{"FontSize", "\[Rule]", "30"}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "21.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5.6"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5.5", ",", "7.5", ",", "11.5", ",", "17.5", ",", "23.5"}], 
       "}"}], ",", "Automatic"}], "}"}]}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"2", "k"}], "-", 
             RowBox[{"3", "/", "2"}]}], ",", 
            RowBox[{"Rotate", "[", 
             RowBox[{
              RowBox[{"MaTeX", "[", 
               RowBox[{
                RowBox[{"\"\<\\\\text{\>\"", "<>", 
                 RowBox[{
                 "method", "\[LeftDoubleBracket]", "k", 
                  "\[RightDoubleBracket]"}], "<>", "\"\<}\>\""}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"\[Pi]", "/", "2"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Length", "[", "method", "]"}]}], "}"}]}], "]"}], ",", 
        "None"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"BaseStyle", "\[Rule]", "16"}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Thick", ",", "16", ",", "Black"}], "]"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"MaTeX", "[", 
       RowBox[{"\"\<\\\\text{Excitation energy (eV)}\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.815391336607777*^9, 3.815391408970666*^9}, {
   3.8153915765783*^9, 3.815391682768703*^9}, {3.815391770429269*^9, 
   3.815391859951474*^9}, {3.8153919192058363`*^9, 3.815392212228739*^9}, {
   3.815392321891568*^9, 3.8153924402101383`*^9}, {3.8153924709245653`*^9, 
   3.815392567876563*^9}, {3.815392629591893*^9, 3.815392719638145*^9}, {
   3.815392770152713*^9, 3.815392817433977*^9}, {3.815392898403816*^9, 
   3.815392905178481*^9}, {3.8153929356979637`*^9, 3.815392949317486*^9}, {
   3.815392995419813*^9, 3.8153930693830633`*^9}, {3.815393140781329*^9, 
   3.8153932067872543`*^9}, {3.815395142627603*^9, 3.815395149446054*^9}, {
   3.815458987991253*^9, 3.815459098583597*^9}, {3.815459329286343*^9, 
   3.8154593377002287`*^9}, {3.8154594678273067`*^9, 3.815459490247451*^9}, {
   3.8157280344483557`*^9, 3.815728063998728*^9}, {3.815728340223858*^9, 
   3.815728415744893*^9}, {3.815728452660318*^9, 3.8157285898041286`*^9}, {
   3.815728649465516*^9, 3.815728670928997*^9}, {3.81572878932498*^9, 
   3.8157287919560537`*^9}, {3.815728842667386*^9, 3.815729029846403*^9}, {
   3.815729090719265*^9, 3.815729234334784*^9}, {3.815729276321967*^9, 
   3.815729411089218*^9}, {3.815729479255727*^9, 3.815729488880513*^9}, {
   3.8157295516375504`*^9, 3.815729582835053*^9}, {3.8157296161415777`*^9, 
   3.815729651400827*^9}, {3.8157324214159613`*^9, 3.815732504794283*^9}, {
   3.815732542690825*^9, 3.815732576685151*^9}, {3.815732626709339*^9, 
   3.815732957867141*^9}, {3.815732990163885*^9, 3.815733011181686*^9}, {
   3.815733281175748*^9, 3.8157334156062593`*^9}, {3.815733538960723*^9, 
   3.815733674125169*^9}, {3.815733836507172*^9, 3.8157338456075687`*^9}, {
   3.815734062774742*^9, 3.815734212106782*^9}, {3.815735484416667*^9, 
   3.815735490272163*^9}, {3.815735525477557*^9, 3.815735569638521*^9}, {
   3.819301583267041*^9, 3.8193016085413322`*^9}, {3.8193017494085627`*^9, 
   3.8193018464115067`*^9}, {3.819343029336529*^9, 3.819343066918728*^9}, {
   3.819343116649365*^9, 3.819343116717484*^9}, {3.819343159074665*^9, 
   3.8193431846918488`*^9}, {3.8193432210110083`*^9, 
   3.8193432211582203`*^9}, {3.819642410654593*^9, 3.819642484837903*^9}, {
   3.819643747220961*^9, 3.819643813869444*^9}, 3.819646602225556*^9, 
   3.819646696546555*^9, {3.819646757710829*^9, 3.819646787268154*^9}, {
   3.8196469381911163`*^9, 3.819646938496934*^9}, {3.819647391467989*^9, 
   3.8196473916167927`*^9}, {3.8199625969944963`*^9, 3.8199626185959787`*^9}, 
   3.819962726387599*^9, {3.819962805959146*^9, 3.819962810893381*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"ce9a37c9-f290-4ff9-8e20-fb2ac069191f"],

Cell[BoxData["`"], "Input",
 CellChangeTimes->{
  3.815733637549346*^9},ExpressionUUID->"afe9eaa6-d491-4b7a-be7d-\
51d4faa79596"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  SubscriptBox["D", 
   RowBox[{"4", "h"}]], 
  TraditionalForm]],ExpressionUUID->"807feb39-7ab4-4773-867b-8890bb8352e2"]], \
"Section",
 CellChangeTimes->{{3.8196438565054092`*^9, 3.819643858041607*^9}, {
  3.819646856676579*^9, 
  3.819646856676668*^9}},ExpressionUUID->"031beb2c-3612-4398-bbed-\
82451a91c66a"],

Cell[CellGroupData[{

Cell["Geometry", "Subsection",
 CellChangeTimes->{{3.820119526099333*^9, 
  3.820119528866288*^9}},ExpressionUUID->"e797c147-2261-4ad9-bf30-\
a876fe039a42"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", 
    RowBox[{"4", "h"}]], TraditionalForm]],ExpressionUUID->
  "d84228b5-a0e0-4cd4-ac52-104804d14f03"],
 " geometry (in angstrom) obtained at the RO-CCSD(T)(full)/aug-cc-pVTZ"
}], "Text",
 CellChangeTimes->{{3.820119534614387*^9, 3.820119562489399*^9}, {
  3.8211849460819263`*^9, 3.8211849475990343`*^9}, {3.821184978173657*^9, 
  3.821184997579742*^9}},ExpressionUUID->"adf832dd-e1af-42ec-b58c-\
cbbbe9c3192b"],

Cell["\<\
C     0.000000    1.017702    0.000000
C     1.017702   -0.000000    0.000000
C    -1.017702    0.000000    0.000000
C    -0.000000   -1.017702    0.000000
H     0.000000    2.092429    0.000000
H     2.092429   -0.000000    0.000000
H    -0.000000   -2.092429    0.000000
H    -2.092429    0.000000    0.000000\
\>", "Text",
 CellChangeTimes->{3.82011957301793*^9, 3.821184944001792*^9, 
  3.821184989643895*^9},ExpressionUUID->"c1f07e0a-8d48-41b9-a295-\
c059851cd566"]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.815728210943774*^9, 
  3.815728212904736*^9}},ExpressionUUID->"0b0b3775-588f-4d6e-8521-\
a48a2543bc88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CBDD4h", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", "CCSD", " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSD\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.148", ",", "1.788", 
       ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.100", ",", "1.650", 
       ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.085", ",", "1.600", 
       ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.084", ",", "1.588", 
       ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CC3", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CC3\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", ",", "1.809", 
       ",", "2.836"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "\"\<\>\"", ",", "1.695", 
       ",", "2.646"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "\"\<\>\"", ",", "1.662", 
       ",", "2.720"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CCSDT", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSDT\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.210", ",", "1.751", 
       ",", "2.565"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.165", ",", "1.659", ",",
        "2.450"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.149", ",", "1.631", ",",
        "2.537"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "\"\<\>\"", ",", 
         "\"\<\>\"", ",", "\"\<\>\""}], "}"}], ","}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CC4\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<\>\"", ",", "1.604", 
       ",", "2.121"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "\"\<\>\"", ",", "1.539", 
       ",", "1.934"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CCSDTQ", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSDTQ\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.205", ",", "1.593", 
       ",", "2.134"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "\"\<\>\"", ",", 
         "\"\<\>\"", ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "\"\<\>\"", ",", 
         "\"\<\>\"", ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "\"\<\>\"", ",", 
         "\"\<\>\"", ",", "\"\<\>\""}], "}"}], ","}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SA2", "-", 
       RowBox[{"CASSCF", 
        RowBox[{"(", 
         RowBox[{"4", ",", "4"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SA2-CASSCF(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.447", ",", 
       "2.257", ",", "3.549"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.438", ",", "2.240", ",",
        "3.443"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.434", ",", "2.234", ",",
        "3.424"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.435", ",", "2.235", ",",
        "3.427"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"CASPT2", 
       RowBox[{"(", 
        RowBox[{"4", ",", "4"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
      "\"\<CASPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.176", ",", 
       "1.588", ",", "1.899"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.137", ",", "1.540", ",",
        "1.708"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.128", ",", "1.506", ",",
        "1.635"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.128", ",", "1.498", ",",
        "1.612"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"4", ",", "4"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SC-NEVPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.083", ",", 
       "1.520", ",", "1.380"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.037", ",", "1.465", ",",
        "1.140"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.024", ",", "1.428", ",",
        "1.055"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.024", ",", "1.420", ",",
        "1.030"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"PC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"4", ",", "4"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<PC-NEVPT2(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.085", ",", 
       "1.496", ",", "1.329"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.039", ",", "1.440", ",",
        "1.088"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.026", ",", "1.403", ",",
        "1.003"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.026", ",", "1.395", ",",
        "0.977"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"MRCI", 
       RowBox[{"(", 
        RowBox[{"4", ",", "4"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
      "\"\<MRCI(4,4)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.297", ",", 
       "1.861", ",", "2.571"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.273", ",", "1.823", ",",
        "2.419"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.271", ",", "1.824", ",",
        "2.415"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.273", ",", "1.825", ",",
        "2.413"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SA2", "-", 
       RowBox[{"CASSCF", 
        RowBox[{"(", 
         RowBox[{"12", ",", "12"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SA2-CASSCF(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.386", 
       ",", "1.974", ",", "2.736"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.374", ",", "1.947", ",",
        "2.649"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.370", ",", "1.943", ",",
        "2.634"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.371", ",", "1.945", ",",
        "2.637"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"CASPT2", 
       RowBox[{"(", 
        RowBox[{"12", ",", "12"}], ")"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CASPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.235", ",", 
       "1.635", ",", "2.170"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.203", ",", "1.588", ",",
        "2.015"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.183", ",", "1.538", ",",
        "1.926"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.179", ",", "1.522", ",",
        "1.898"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"12", ",", "12"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SC-NEVPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.218", ",",
        "1.644", ",", "2.143"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.189", ",", "1.600", ",",
        "1.991"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.165", ",", "1.546", ",",
        "1.892"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.160", ",", "1.529", ",",
        "1.862"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"PC", "-", 
       RowBox[{"NEVPT2", 
        RowBox[{"(", 
         RowBox[{"12", ",", "12"}], ")"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<PC-NEVPT2(12,12)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "0.189", ",",
        "1.579", ",", "2.020"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", "0.156", ",", "1.530", ",",
        "1.854"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", "0.131", ",", "1.476", ",",
        "1.756"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", "0.126", ",", "1.460", ",",
        "1.727"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "CIPSI", " ", "*)"}], "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<CIPSI\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"0.201", ",", "0.003"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"1.602", ",", "0.007"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"2.126", ",", "0.041"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"0.157", ",", "0.003"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"1.587", ",", "0.005"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"2.102", ",", "0.027"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"0.169", ",", "0.029"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"1.630", ",", "0.045"}], "]"}], ",", "\"\<\>\""}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.819646448046678*^9, 3.819646463831727*^9}, {
   3.819646500151936*^9, 3.81964650448241*^9}, {3.819907670630348*^9, 
   3.819907680355007*^9}, {3.819962436524386*^9, 3.819962471830098*^9}, {
   3.8201195944406433`*^9, 3.820119675784534*^9}, {3.8201197144809713`*^9, 
   3.820119767498103*^9}, {3.82011984563081*^9, 3.8201200473136063`*^9}, {
   3.8201200855889997`*^9, 3.820120304294695*^9}, {3.8202508303996363`*^9, 
   3.820250847512038*^9}, {3.820250944603057*^9, 3.820251093336108*^9}, {
   3.820251292806981*^9, 3.82025129610933*^9}, {3.820386247967042*^9, 
   3.8203862577081842`*^9}, {3.820386652104602*^9, 3.820386669162932*^9}, {
   3.820387145953229*^9, 3.820387315628099*^9}, {3.820387362282827*^9, 
   3.8203875002604113`*^9}, {3.820387567195519*^9, 3.820387608666377*^9}, {
   3.820387681896881*^9, 3.820387685742483*^9}, {3.820387721021719*^9, 
   3.820387855833411*^9}, {3.8203878974670057`*^9, 3.8203879474560003`*^9}, {
   3.820387996014256*^9, 3.820388152182413*^9}, {3.820393442050746*^9, 
   3.8203934433201036`*^9}, {3.820394109611664*^9, 3.820394159220438*^9}, {
   3.8204809907616653`*^9, 3.820480996307027*^9}, {3.8210700849886923`*^9, 
   3.821070088733666*^9}, {3.821765026273364*^9, 3.82176502667826*^9}, {
   3.821977052085271*^9, 3.8219770624288*^9}, {3.8219773702956257`*^9, 
   3.82197737334846*^9}, {3.8221150819452868`*^9, 3.8221150855795813`*^9}, {
   3.822115128961611*^9, 3.822115135538053*^9}, {3.8222083221670933`*^9, 
   3.822208325988398*^9}, {3.822208455468726*^9, 3.8222085735230017`*^9}, {
   3.8222086157132473`*^9, 3.8222088680093107`*^9}, {3.822209117066742*^9, 
   3.822209118660571*^9}, {3.822534268723839*^9, 3.822534508477659*^9}, {
   3.822534838550408*^9, 3.82253484156743*^9}, {3.822534916177457*^9, 
   3.82253492037341*^9}, {3.82266757202337*^9, 3.8226677741352177`*^9}, {
   3.823398250003982*^9, 3.82339825372221*^9}, {3.823530261196929*^9, 
   3.823530261629972*^9}, {3.8236013781749487`*^9, 3.82360138186401*^9}, {
   3.823841211853981*^9, 3.823841227384519*^9}, {3.823841329314184*^9, 
   3.823841376665866*^9}, {3.8238414126421013`*^9, 3.823841478257341*^9}, 
   3.82384814736106*^9, {3.823924601476953*^9, 3.8239246078454*^9}, {
   3.824093339810763*^9, 3.824093342003581*^9}, {3.824093390875629*^9, 
   3.824093420113261*^9}, {3.824093511874815*^9, 3.824093514087389*^9}, {
   3.824093561523301*^9, 3.824093564117529*^9}, {3.824182865339971*^9, 
   3.824182876065481*^9}, {3.824189729992902*^9, 3.8241897346480627`*^9}, {
   3.824206654273285*^9, 3.824206681032576*^9}, {3.824441669654945*^9, 
   3.824441697834568*^9}, 3.8244417666411533`*^9, {3.824481759698242*^9, 
   3.824481772257951*^9}, {3.824616959315894*^9, 3.824616968199109*^9}, {
   3.824617029162079*^9, 3.8246170854291067`*^9}, 3.824797966620908*^9, {
   3.8247980371849403`*^9, 3.824798040181305*^9}, {3.8249897672092257`*^9, 
   3.824989774674591*^9}, {3.824989962333706*^9, 3.824989967362425*^9}, {
   3.8256748573917227`*^9, 3.825674861641438*^9}, {3.825674943622177*^9, 
   3.825674950484906*^9}, {3.825752246872456*^9, 3.82575227566343*^9}, {
   3.8257584292108192`*^9, 3.8257584614289618`*^9}, {3.8257584997186613`*^9, 
   3.8257585004026318`*^9}, {3.8260056639871597`*^9, 3.826005675991169*^9}, {
   3.8260058590826197`*^9, 3.82600586330814*^9}, {3.826006057615621*^9, 
   3.826006078515778*^9}},ExpressionUUID->"0fe9f196-cce7-4233-9666-\
614981e2b593"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CBDD4hSF", "=", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"(*", " ", 
     RowBox[{"SF", "-", "CIS"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<SF-CIS\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.1087"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.1675", "+", "0.1874"}], ",", "2.0439"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.5542", "+", "0.1874"}], ",", "0.0370"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.9140", "+", "0.1874"}], ",", "0.0365"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.1114"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.1837", "+", "0.1342"}], ",", "2.0490"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4587", "+", "0.1342"}], ",", "0.0475"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.9182", "+", "0.1342"}], ",", "0.0373"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.1138"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.2018", "+", "0.1037"}], ",", "2.0530"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4721", "+", "0.1037"}], ",", "0.0500"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.9492", "+", "0.1037"}], ",", "0.0391"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.1140"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.2036", "+", "0.1023"}], ",", "2.0534"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.4751", "+", "0.1023"}], ",", "0.0503"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2.9538", "+", "0.1023"}], ",", "0.0392"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"CIS", 
        RowBox[{"(", "D", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"SF", "-", "TD", "-", 
        RowBox[{"BLYP", "\[IndentingNewLine]", " ", 
         RowBox[{"{", 
          RowBox[{"\"\<SF-TD-BLYP\>\"", ",", "\"\<6-31+G(d)\>\"", ","}], 
          "}"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ","}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ","}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ","}], "}"}], ","}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "B3LYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-B3LYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0139"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0028", "-", "1.0185"}], ",", "2.0056"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5059", "-", "1.0185"}], ",", "0.0110"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5604", "-", "1.0185"}], ",", "0.0110"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0138"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9796", "-", "0.9983"}], ",", "2.0059"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4751", "-", "0.9983"}], ",", "0.0110"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5340", "-", "0.9983"}], ",", "0.0107"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0144"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9954", "-", "1.0158"}], ",", "2.0065"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4882", "-", "1.0158"}], ",", "0.0116"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5488", "-", "1.0158"}], ",", "0.0112"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0144"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9976", "-", "1.0180"}], ",", "2.0065"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4907", "-", "1.0180"}], ",", "0.0117"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5513", "-", "1.0180"}], ",", "0.0113"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "PBE0"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-PBE0\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0166"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0887", "-", "1.1004"}], ",", "2.0078"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7184", "-", "1.1004"}], ",", "0.0105"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7895", "-", "1.1004"}], ",", "0.0104"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0169"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0695", "-", "1.0858"}], ",", "2.0084"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.6878", "-", "1.0858"}], ",", "0.0113"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7657", "-", "1.0858"}], ",", "0.0106"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0177"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0960", "-", "1.1146"}], ",", "2.0093"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7112", "-", "1.1146"}], ",", "0.0121"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7912", "-", "1.1146"}], ",", "0.0115"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0178"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0985", "-", "1.1170"}], ",", "2.0094"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7140", "-", "1.1170"}], ",", "0.0122"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7940", "-", "1.1170"}], ",", "0.0116"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "BHHLYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-BHHLYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0418"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5370", "-", "0.4734"}], ",", "2.0169"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7788", "-", "0.4734"}], ",", "0.0179"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.9315", "-", "0.4734"}], ",", "0.0177"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0421"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5269", "-", "0.4759"}], ",", "2.0182"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7364", "-", "0.4759"}], ",", "0.0200"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.9131", "-", "0.4759"}], ",", "0.0175"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0428"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5409", "-", "0.4955"}], ",", "2.0195"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7447", "-", "0.4955"}], ",", "0.0208"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.9269", "-", "0.4955"}], ",", "0.0182"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0429"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5431", "-", "0.4975"}], ",", "2.0196"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7476", "-", "0.4975"}], ",", "0.0209"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.9300", "-", "0.4975"}], ",", "0.0183"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "M06", "-", 
       RowBox[{"2", "X"}]}], " ", "*)"}], "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-M06-2X\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0463"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4518"}], "+", "0.5533"}], ",", "2.0114"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9228", "+", "0.5533"}], ",", "0.0112"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0867", "+", "0.5533"}], ",", "0.0108"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0466"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4519"}], "+", "0.5380"}], ",", "2.0127"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.8811", "+", "0.5380"}], ",", "0.0137"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0732", "+", "0.5380"}], ",", "0.0106"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0471"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.3821"}], "+", "0.4602"}], ",", "2.0140"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9433", "+", "0.4602"}], ",", "0.0153"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.1421", "+", "0.4602"}], ",", "0.0120"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0474"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.4055"}], "+", "0.4847"}], ",", "2.0137"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9231", "+", "0.4847"}], ",", "0.0152"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.1221", "+", "0.4847"}], ",", "0.0119"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "TD", "-", "CAM", "-", "B3LYP"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-CAM-B3LYP\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0219"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9158", "-", "0.8952"}], ",", "2.0061"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4983", "-", "0.8952"}], ",", "0.0114"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5669", "-", "0.8952"}], ",", "0.0111"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0222"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.8964", "-", "0.8839"}], ",", "2.0075"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4691", "-", "0.8839"}], ",", "0.0126"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5504", "-", "0.8839"}], ",", "0.0111"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0227"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9089", "-", "0.8986"}], ",", "2.0082"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4787", "-", "0.8986"}], ",", "0.0132"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5621", "-", "0.8986"}], ",", "0.0116"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0228"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.9107", "-", "0.9004"}], ",", "2.0083"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4808", "-", "0.9004"}], ",", "0.0132"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.5642", "-", "0.9004"}], ",", "0.0116"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "\[Omega]B97X", "-", "V"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-\[Omega]B97X-V\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0234"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7713", "-", "0.7309"}], ",", "2.0054"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3308", "-", "0.7309"}], ",", "0.0090"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4014", "-", "0.7309"}], ",", "0.0085"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0243"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7530", "-", "0.7244"}], ",", "2.0074"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3007", "-", "0.7244"}], ",", "0.0113"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3888", "-", "0.7244"}], ",", "0.0092"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0247"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7696", "-", "0.7431"}], ",", "2.0081"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3148", "-", "0.7431"}], ",", "0.0119"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4049", "-", "0.7431"}], ",", "0.0096"}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0248"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.7720", "-", "0.7455"}], ",", "2.0082"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3175", "-", "0.7455"}], ",", "0.0120"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.4076", "-", "0.7455"}], ",", "0.0097"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "M11"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-M11\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0416"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0343"}], "+", "0.1361"}], ",", "2.0087"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.1004", "+", "0.1361"}], ",", "0.0139"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2378", "+", "0.1361"}], ",", "0.0137"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0425"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0289"}], "+", "0.1157"}], ",", "2.0111"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0806", "+", "0.1157"}], ",", "0.0166"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2461", "+", "0.1157"}], ",", "0.0138"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0428"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0157"}], "+", "0.0970"}], ",", "2.0117"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.0908", "+", "0.0970"}], ",", "0.0169"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2617", "+", "0.0970"}], ",", "0.0138"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0426"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.0005", "+", "0.0794"}], ",", "2.0118"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.1054", "+", "0.0794"}], ",", "0.0167"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2776", "+", "0.0794"}], ",", "0.0134"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "TD", "-", "LC", "-", "\[Omega]PBE08"}], " ", "*)"}],
      "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-TD-LC-\[Omega]PBE08\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0300"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2290", "-", "1.1509"}], ",", "2.0066"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7439", "-", "1.1509"}], ",", "0.0103"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8138", "-", "1.1509"}], ",", "0.0095"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0319"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2232", "-", "1.1633"}], ",", "2.0112"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7264", "-", "1.1633"}], ",", "0.0143"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8226", "-", "1.1633"}], ",", "0.0110"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0327"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2465", "-", "1.1883"}], ",", "2.0124"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7489", "-", "1.1883"}], ",", "0.0153"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8467", "-", "1.1883"}], ",", "0.0118"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.0328"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.2484", "-", "1.1902"}], ",", "2.0125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.7510", "-", "1.1902"}], ",", "0.0153"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.8488", "-", "1.1902"}], ",", "0.0119"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"SF", "-", "TD", "-", 
        RowBox[{"B2PLYP", " ", "\[IndentingNewLine]", " ", 
         RowBox[{"{", 
          RowBox[{"\"\<SF-TD-B2PLYP\>\"", ",", "\"\<6-31+G(d)\>\"", ","}], 
          "}"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ","}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ","}], "}"}], ","}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"ADC", 
        RowBox[{"(", "2", ")"}]}], "-", "s"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-ADC(2)-s\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.200741", "+", "0.143834"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.615869", "+", "0.143834"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.951672", "+", "0.143834"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.214450", "+", "0.054460"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.601562", "+", "0.054460"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.839252", "+", "0.054460"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.222666", "+", "0.033673"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.578746", "+", "0.033673"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.810565", "+", "0.033673"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\""}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"ADC", 
        RowBox[{"(", "2", ")"}]}], "-", "x"}], " ", "*)"}], 
     "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<SF-ADC(2)-x\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.486598"}], "+", "0.750402"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.430900", "+", "0.750402"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.221429", "+", "0.750402"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.485246"}], "+", "0.701437"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.405620", "+", "0.701437"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.058402", "+", "0.701437"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.470222"}], "+", "0.681740"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.409219", "+", "0.681740"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.049092", "+", "0.681740"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", 
       RowBox[{"ADC", 
        RowBox[{"(", "3", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", " ", 
     
     RowBox[{"{", 
      RowBox[{"\"\<SF-ADC(3)\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.163307"}], "+", "0.286504"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.363229", "+", "0.286504"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.791624", "+", "0.286504"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.156094"}], "+", "0.244088"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.326597", "+", "0.244088"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.633507", "+", "0.244088"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.154926"}], "+", "0.234351"}], ",", "\"\<\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.341077", "+", "0.234351"}], ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.618891", "+", "0.234351"}], ",", "\"\<\>\""}], "}"}]}], 
      "}"}]}], "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"SF", "-", "EOM", "-", 
       RowBox[{"CCSD", " ", "\[IndentingNewLine]", " ", 
        RowBox[{"{", 
         RowBox[{"\"\<SF-EOM-CCSD\>\"", ",", "\"\<6-31+G(d)\>\"", ","}], 
         "}"}]}]}], ",", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ","}], "}"}], ",", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ","}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"SF", "-", "EOM", "-", "CCSD"}], " ", "*)"}], 
      "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-EOM-CC(2,3)\>\"", ",", "\"\<6-31+G(d)\>\"", ","}], 
       "}"}], ",", "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ","}], "}"}]}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"SF", "-", "XX"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<SF-XX\>\"", ",", "\"\<6-31+G(d)\>\"", ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVDZ\>\"", ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVTZ\>\"", ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<aug-cc-pVQZ\>\"", ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}], ",", 
         RowBox[{"{", ",", "}"}]}], "}"}]}], "*)"}], "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8273783482265882`*^9, 3.82737834834779*^9}, {
   3.827378436065933*^9, 3.827378771365574*^9}, {3.827378813427616*^9, 
   3.827379091557262*^9}, {3.8273791354993067`*^9, 3.8273791414302464`*^9}, {
   3.82737919008083*^9, 3.8273791910909557`*^9}, {3.827379422501924*^9, 
   3.8273795005617*^9}, {3.827379538167843*^9, 3.827379663370778*^9}, {
   3.827379750807979*^9, 3.827379887949132*^9}, {3.8273799847271347`*^9, 
   3.827380034676241*^9}, {3.827380068852826*^9, 3.827380284502809*^9}, {
   3.82738050387869*^9, 3.827380532090897*^9}, {3.827380679687331*^9, 
   3.8273806906119423`*^9}, {3.82745399530021*^9, 3.827454420843693*^9}, {
   3.827454838429389*^9, 3.827455461945928*^9}, {3.8274554951989098`*^9, 
   3.827456055785171*^9}, {3.827456612524187*^9, 3.8274568358015633`*^9}, {
   3.82745687030919*^9, 3.827456872047348*^9}, 3.82746096528141*^9, {
   3.827466569464957*^9, 3.82746696011477*^9}, {3.827467024417012*^9, 
   3.827467042934304*^9}, {3.8274671039856167`*^9, 3.82746744548771*^9}, {
   3.827467480471951*^9, 3.827467507103756*^9}, {3.827467543550809*^9, 
   3.827467786120056*^9}, {3.827467909911384*^9, 3.827467912456791*^9}, {
   3.827467957273602*^9, 3.8274680029965076`*^9}, {3.827468127427394*^9, 
   3.8274681309001703`*^9}, {3.827468185711769*^9, 3.827468198040874*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"86ef0a50-daa3-492e-bff4-0c102d15e915"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table of excitation energies", "Subsection",
 CellChangeTimes->{{3.81246742284888*^9, 3.812467426356081*^9}, {
  3.815728206364393*^9, 3.81572820807975*^9}, {3.8196448855339518`*^9, 
  3.819644895161807*^9}},ExpressionUUID->"29d9a581-07ec-4f13-a8a0-\
7566f2d2f79d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"SetAccuracy", "[", 
    RowBox[{"CBDD4hSF", ",", "4"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Method\>\"", ",", "\"\<Basis\>\"", ",", 
        "\"\<1\!\(\*SuperscriptBox[\(\\\ \), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(1  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(3\)]\)\!\(\*SubscriptBox[\(A\), \(2  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(1  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(2  g\)]\)\>\""}], "}"}]}], "}"}]}], ",", 
   " ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.827380550499913*^9, 3.8273805513764467`*^9}, {
  3.827380647200301*^9, 3.8273806629324627`*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"e8d3b26f-3e58-4a8e-a660-5c2cf37c7202"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Method\"\>", "\<\"Basis\"\>", "\<\"1\\!\\(\\*SuperscriptBox[\\(\\\\ \
\\), \\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(B\\), \\(1  g\\)]\\)\"\>", "\<\"1 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(3\\)]\\)\\!\\(\
\\*SubscriptBox[\\(A\\), \\(2  g\\)]\\)\"\>", "\<\"1 \\!\\(\\*SuperscriptBox[\
\\(\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(A\\), \
\\(1  g\\)]\\)\"\>", "\<\"1 \\!\\(\\*SuperscriptBox[\\(\
\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(B\\), \
\\(2  g\\)]\\)\"\>"},
    {"\<\"SF-CIS\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.108700000000000005`3.0362295440862943"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.3548999999999999932`3.5501059993475925"},
       {"2.043899999999999828`4.31045964365906"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.7416000000000000369`4.438004091421811"},
       {"0.0369999999999999982`2.568201724066995"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.1013999999999999346`4.491557782551335"},
       {"0.0364999999999999977`2.562292864456474"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.111399999999999999`3.04688519083771"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.3179000000000000159`3.5022905279147727"},
       {"2.0489999999999999325`4.311541958401195"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.5928999999999997605`4.413785767719738"},
       {"0.0475000000000000006`2.6766936096248664"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.0524000000000000021`4.4846414448824135"},
       {"0.0372999999999999998`2.5717088318086874"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.1137999999999999984`3.0561422620590526"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.3054999999999999938`3.485011214578573"},
       {"2.0529999999999999361`4.312388949370592"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.5758000000000000895`4.4109121388630825"},
       {"0.0500000000000000028`2.6989700043360183"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.052899999999999725`4.484712578894317"},
       {"0.0391000000000000028`2.5921767573958667"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.1140000000000000041`3.0569048513364723"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.3059000000000000052`3.4855794769846784"},
       {"2.053399999999999892`4.312473557686055"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.5773999999999999133`4.411181824182252"},
       {"0.0502999999999999975`2.7015679850559273"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"3.0561000000000002608`4.485167560878013"},
       {"0.0391999999999999987`2.593286067020457"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-B3LYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0138999999999999992`2.143014800254095"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0157000000000000473`2.195899652409235"}]},
       {"2.0055999999999998273`4.302244320950161"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.4874000000000000554`3.6878855248487055"},
       {"0.0109999999999999994`2.041392685158225"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5419000000000000483`3.733919151012391"},
       {"0.0109999999999999994`2.041392685158225"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0137999999999999998`2.1398790864012365"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0186999999999999389`2.2718416065364972"}]},
       {"2.0059000000000000163`4.302309278369985"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.4768000000000001126`3.6783362467321803"},
       {"0.0109999999999999994`2.041392685158225"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.535700000000000065`3.728921646372859"},
       {"0.0106999999999999994`2.0293837776852097"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0143999999999999996`2.1583624920952493"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0204000000000000847`2.3096301674259005"}]},
       {"2.0064999999999999503`4.302439164069857"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.4723999999999999311`3.6743098889414774"},
       {"0.0115999999999999992`2.064457989226918"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5329999999999999183`3.7267272090265724"},
       {"0.0111999999999999999`2.0492180226701815"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0143999999999999996`2.1583624920952493"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0203999999999999737`2.3096301674258983"}]},
       {"2.0064999999999999503`4.302439164069857"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.472699999999999898`3.6745856023029138"},
       {"0.0117000000000000003`2.0681858617461617"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5332999999999998852`3.7269715836828765"},
       {"0.0112999999999999993`2.0530784434834195"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-PBE0\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0166000000000000002`2.220108088040055"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0117000000000000437`2.068185861746163"}]},
       {"2.0078000000000000291`4.3027204498961344"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6179999999999998828`3.790988475088816"},
       {"0.0105000000000000007`2.0211892990699383"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6891000000000000458`3.8382822499146885"},
       {"0.0103999999999999995`2.0170333392987803"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0168999999999999984`2.2278867046136734"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0163000000000002032`2.212187604403963"}]},
       {"2.0083999999999999631`4.302850212702309"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6019999999999998685`3.7795964912578244"},
       {"0.0112999999999999993`2.0530784434834195"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6798999999999999488`3.832445041174111"},
       {"0.0106`2.0253058652647704"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0177000000000000005`2.2479732663618064"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0185999999999999499`2.269512944217915"}]},
       {"2.009300000000000086`4.303044784243365"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5966000000000000192`3.7756832490260437"},
       {"0.0120999999999999996`2.08278537031645"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6765999999999998682`3.8303319934519617"},
       {"0.0114999999999999998`2.060697840353612"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0177999999999999999`2.2504200023088936"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {
        RowBox[{"-", "0.0184999999999999609`2.267171728403013"}]},
       {"2.0093999999999998529`4.30306639792351"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5969999999999999751`3.7759743311293694"},
       {"0.0122000000000000008`2.0863598306747484"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6770000000000000462`3.8305886686851442"},
       {"0.0115999999999999992`2.064457989226918"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-BHHLYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0417999999999999969`2.621176281775035"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0636000000000000454`2.803457115648414"},
       {"2.0169000000000001371`4.304684365974387"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.3053999999999998938`4.115743608359958"},
       {"0.0178999999999999992`2.252853030979893"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4580999999999999517`4.163787309962003"},
       {"0.0177000000000000005`2.2479732663618064"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0420999999999999985`2.6242820958356683"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0510000000000000453`2.7075701760979367"},
       {"2.018200000000000216`4.30496420183769"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.2604999999999999538`4.100542850012465"},
       {"0.0200000000000000004`2.3010299956639813"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.437200000000000033`4.157517208532612"},
       {"0.0175000000000000017`2.2430380486862944"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0427999999999999978`2.6314437690131722"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0454000000000000514`2.657055852857104"},
       {"2.0194999999999998508`4.305243857506007"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.2491999999999998661`4.096631975558161"},
       {"0.020799999999999999`2.3180633349627615"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4314000000000000057`4.155761012877924"},
       {"0.0182000000000000009`2.2600713879850747"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0429000000000000006`2.632457292184724"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0456000000000000294`2.6589648426644357"},
       {"2.0196000000000000618`4.305265362023449"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.250099999999999989`4.09694475517694"},
       {"0.0208999999999999984`2.320146286111054"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4324999999999998845`4.156094630639427"},
       {"0.0183000000000000003`2.2624510897304293"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-M06-2X\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0463000000000000009`2.665580991017953"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.1015000000000000346`3.0064660422492318"},
       {"2.0114000000000000767`4.3034984457923136"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4760999999999999677`4.169115780235715"},
       {"0.0111999999999999999`2.0492180226701815"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6400000000000001243`4.214843848047698"},
       {"0.0108000000000000006`2.03342375548695"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0466000000000000025`2.66838591669"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0861000000000000099`2.935003151453655"},
       {"2.0127000000000001556`4.3037790465955315"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4191000000000000281`4.152013000050834"},
       {"0.0137000000000000004`2.1367205671564067"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6111999999999999655`4.207149453209543"},
       {"0.0106`2.0253058652647704"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.047100000000000003`2.673020907128896"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0781000000000000028`2.8926510338773"},
       {"2.0139999999999997904`4.304059466217599"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4034999999999999698`4.147212416970458"},
       {"0.0152999999999999994`2.184691430817599"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6022999999999998355`4.2047438326888"},
       {"0.0120000000000000002`2.0791812460476247"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0473999999999999977`2.675778341674085"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0791999999999999926`2.8987251815894934"},
       {"2.0137000000000000455`4.303994770066042"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.4077999999999999403`4.148540960867229"},
       {"0.0152`2.1818435879447726"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6068000000000002281`4.205961823059634"},
       {"0.0119000000000000009`2.0755469613925306"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-CAM-B3LYP\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0218999999999999993`2.340444114840118"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0205999999999999517`2.3138672203691524"},
       {"2.0060999999999999943`4.302352577919563"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6030999999999999694`3.7803893284709527"},
       {"0.0114000000000000004`2.0569048513364727"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6716999999999999638`3.8271753482986925"},
       {"0.0111000000000000005`2.045322978786657"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.022200000000000001`2.3463529744506384"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0124999999999999556`2.096910013008055"},
       {"2.0074999999999998401`4.302655553950719"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5852000000000000535`3.7673043174532737"},
       {"0.0126000000000000001`2.100370545117563"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6664999999999999813`3.823800153749878"},
       {"0.0111000000000000005`2.045322978786657"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0227000000000000014`2.3560258571931225"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0103000000000000869`2.012837224705176"},
       {"2.0081999999999999851`4.30280696274142"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.580099999999999949`3.7635028654675966"},
       {"0.0131999999999999999`2.1205739312058496"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6635000000000000897`3.821840927200454"},
       {"0.0115999999999999992`2.064457989226918"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0228000000000000008`2.357934847000454"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0102999999999999758`2.012837224705171"},
       {"2.0083000000000001961`4.3028285882602555"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.580399999999999916`3.7637274037656985"},
       {"0.0131999999999999999`2.1205739312058496"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6638000000000000567`3.822037248072585"},
       {"0.0115999999999999992`2.064457989226918"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-\[Omega]B97X-V\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0234000000000000007`2.369215857410143"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0403999999999999915`2.6063813651106047"},
       {"2.0053999999999998494`4.302201010605382"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5998999999999999888`3.778078861937455"},
       {"0.0089999999999999993`1.9542425094393248"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6704999999999999849`3.826398782187618"},
       {"0.0085000000000000006`1.9294189257142926"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0242999999999999987`2.385606273598312"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0285999999999999588`2.4563660331290427"},
       {"2.0074000000000000732`4.302633919813779"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5762999999999999234`3.760648619581356"},
       {"0.0112999999999999993`2.0530784434834195"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6643999999999999906`3.8224296237793567"},
       {"0.0091999999999999998`1.9637878273455551"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0246999999999999997`2.392696953259666"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.026499999999999968`2.423245873936807"},
       {"2.0081000000000002181`4.302785336145699"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.571699999999999986`3.7571681922142726"},
       {"0.0119000000000000009`2.0755469613925306"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6618000000000000549`3.8207267628238344"},
       {"0.0095999999999999992`1.9822712330395682"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0247999999999999991`2.3944516808262164"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.026499999999999968`2.423245873936807"},
       {"2.0081999999999999851`4.30280696274142"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5719999999999998419`3.757396028793024"},
       {"0.0120000000000000002`2.0791812460476247"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6620999999999999108`3.8209235878813175"},
       {"0.0097000000000000003`1.9867717342662448"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-M11\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0415999999999999981`2.6190933306267423"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.1018000000000000016`3.00774777800074"},
       {"2.0087000000000001521`4.302915079568861"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.2364999999999999325`4.092194120697316"},
       {"0.0138999999999999992`2.143014800254095"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.3738999999999998991`4.13795512353236"},
       {"0.0137000000000000004`2.1367205671564067"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0425000000000000031`2.628388930050311"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0868000000000000022`2.9385197251764916"},
       {"2.0110999999999998877`4.303433666006204"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.196299999999999919`4.077840102734993"},
       {"0.0166000000000000002`2.220108088040055"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.3617999999999998995`4.134113329842324"},
       {"0.0137999999999999998`2.1398790864012365"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0427999999999999978`2.6314437690131722"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0813000000000000111`2.910090545594068"},
       {"2.0116999999999998217`4.303563215917248"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.187799999999999967`4.074743320941003"},
       {"0.0168999999999999984`2.2278867046136734"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.3587000000000000188`4.13312357540262"},
       {"0.0137999999999999998`2.1398790864012365"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.042599999999999999`2.629409599102719"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0798999999999999988`2.9025467793139916"},
       {"2.0118000000000000327`4.3035848038124636"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.1847999999999998533`4.073645045513152"},
       {"0.0166999999999999996`2.2227164711475833"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.356999999999999984`4.132579847659737"},
       {"0.0134000000000000005`2.1271047983648077"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-TD-LC-\[Omega]PBE08\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"0.0299999999999999989`2.4771212547196626"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0781000000000000583`2.8926510338773004"},
       {"2.0066000000000001613`4.302460807910379"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5929999999999999716`3.7730546933642626"},
       {"0.0103000000000000001`2.012837224705172"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6629000000000000448`3.8214480190175304"},
       {"0.0094999999999999998`1.9777236052888476"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"0.0318999999999999978`2.503790683057181"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0599000000000000643`2.7774268223893115"},
       {"2.0112000000000000988`4.303455260341883"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5630999999999999339`3.7505855273410087"},
       {"0.0143000000000000002`2.155336037465062"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6592999999999999972`3.819083075743703"},
       {"0.0109999999999999994`2.041392685158225"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"0.0326999999999999999`2.5145477526602864"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0582000000000000295`2.764922984649889"},
       {"2.0123999999999999666`4.303714308653711"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5605999999999999872`3.748653093424267"},
       {"0.0152999999999999994`2.184691430817599"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6584000000000000963`3.8184898222042136"},
       {"0.0117999999999999997`2.0718820073061255"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", GridBox[{
       {"0``4."},
       {"0.0328000000000000028`2.5158738437116788"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0582000000000000295`2.764922984649889"},
       {"2.0125000000000001776`4.303735889039906"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.5607999999999999652`3.748808004958602"},
       {"0.0152999999999999994`2.184691430817599"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.6586000000000000743`3.818621726375889"},
       {"0.0119000000000000009`2.0755469613925306"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-ADC(2)-s\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.3445749999999999647`3.5372837648244126"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7597030000000000172`4.2454393744360255"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.0955059999999998688`4.3212889086741155"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.2689099999999999824`3.429606952703283"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.656021999999999883`4.219066102023219"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.8937120000000000619`4.277313931203006"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.2563389999999999835`3.4088146857639363"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.6124190000000000467`4.207477907036545"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.844238000000000044`4.265816966292956"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\
\<\"\"\>"},
    {"\<\"SF-ADC(2)-x\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.2638040000000000385`3.4212813763686385"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.1813020000000000742`4.072360939245152"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.9718310000000001114`4.294869690061266"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.2161909999999999665`3.3348376103772623"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.1070569999999999578`4.04416998234952"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7598389999999999311`4.245472937922166"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.2115180000000000393`3.3253473313708346"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.0909590000000000121`4.037808429407458"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.7308319999999999261`4.238254915932136"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"SF-ADC(3)\"\>", "\<\"6-31+G(d)\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.1231969999999999732`3.090600132347002"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.649732999999999894`4.21741366178383"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"2.0781279999999999752`4.317672293934178"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0879939999999999889`2.9444530601532546"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5706850000000001089`4.196089096256561"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.877595000000000125`4.2736019200740785"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]},
    {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", GridBox[{
       {"0``4."},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"0.0794249999999999956`2.899957223499185"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.5754280000000000506`4.197398559895156"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}], GridBox[{
       {"1.8532420000000000559`4.267932134052997"},
       {"\<\"\"\>"}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}}]}
   },
   GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  TableForm[{{
    "SF-CIS", "6-31+G(d)", {0``4., 0.108700000000000005`3.0362295440862943}, {
     0.3548999999999999932`3.5501059993475925, 
      2.043899999999999828`4.31045964365906}, {
     2.7416000000000000369`4.438004091421811, 
      0.0369999999999999982`2.568201724066995}, {
     3.1013999999999999346`4.491557782551335, 
      0.0364999999999999977`2.562292864456474}}, {
    "", "aug-cc-pVDZ", {0``4., 0.111399999999999999`3.04688519083771}, {
     0.3179000000000000159`3.5022905279147727, 
      2.0489999999999999325`4.311541958401195}, {
     2.5928999999999997605`4.413785767719738, 
      0.0475000000000000006`2.6766936096248664}, {
     3.0524000000000000021`4.4846414448824135, 
      0.0372999999999999998`2.5717088318086874}}, {
    "", "aug-cc-pVTZ", {0``4., 0.1137999999999999984`3.0561422620590526}, {
     0.3054999999999999938`3.485011214578573, 
      2.0529999999999999361`4.312388949370592}, {
     2.5758000000000000895`4.4109121388630825, 
      0.0500000000000000028`2.6989700043360183}, {
     3.052899999999999725`4.484712578894317, 
      0.0391000000000000028`2.5921767573958667}}, {
    "", "aug-cc-pVQZ", {0``4., 0.1140000000000000041`3.0569048513364723}, {
     0.3059000000000000052`3.4855794769846784, 
      2.053399999999999892`4.312473557686055}, {
     2.5773999999999999133`4.411181824182252, 
      0.0502999999999999975`2.7015679850559273}, {
     3.0561000000000002608`4.485167560878013, 
      0.0391999999999999987`2.593286067020457}}, {
    "SF-TD-B3LYP", "6-31+G(d)", {
     0``4., 0.0138999999999999992`2.143014800254095}, \
{-0.0157000000000000473`2.195899652409235, 
      2.0055999999999998273`4.302244320950161}, {
     0.4874000000000000554`3.6878855248487055, 
      0.0109999999999999994`2.041392685158225}, {
     0.5419000000000000483`3.733919151012391, 
      0.0109999999999999994`2.041392685158225}}, {
    "", "aug-cc-pVDZ", {
     0``4., 0.0137999999999999998`2.1398790864012365}, \
{-0.0186999999999999389`2.2718416065364972, 
      2.0059000000000000163`4.302309278369985}, {
     0.4768000000000001126`3.6783362467321803, 
      0.0109999999999999994`2.041392685158225}, {
     0.535700000000000065`3.728921646372859, 
      0.0106999999999999994`2.0293837776852097}}, {
    "", "aug-cc-pVTZ", {
     0``4., 0.0143999999999999996`2.1583624920952493}, \
{-0.0204000000000000847`2.3096301674259005, 
      2.0064999999999999503`4.302439164069857}, {
     0.4723999999999999311`3.6743098889414774, 
      0.0115999999999999992`2.064457989226918}, {
     0.5329999999999999183`3.7267272090265724, 
      0.0111999999999999999`2.0492180226701815}}, {
    "", "aug-cc-pVQZ", {
     0``4., 0.0143999999999999996`2.1583624920952493}, \
{-0.0203999999999999737`2.3096301674258983, 
      2.0064999999999999503`4.302439164069857}, {
     0.472699999999999898`3.6745856023029138, 
      0.0117000000000000003`2.0681858617461617}, {
     0.5332999999999998852`3.7269715836828765, 
      0.0112999999999999993`2.0530784434834195}}, {
    "SF-TD-PBE0", "6-31+G(d)", {
     0``4., 0.0166000000000000002`2.220108088040055}, \
{-0.0117000000000000437`2.068185861746163, 
      2.0078000000000000291`4.3027204498961344}, {
     0.6179999999999998828`3.790988475088816, 
      0.0105000000000000007`2.0211892990699383}, {
     0.6891000000000000458`3.8382822499146885, 
      0.0103999999999999995`2.0170333392987803}}, {
    "", "aug-cc-pVDZ", {
     0``4., 0.0168999999999999984`2.2278867046136734}, \
{-0.0163000000000002032`2.212187604403963, 
      2.0083999999999999631`4.302850212702309}, {
     0.6019999999999998685`3.7795964912578244, 
      0.0112999999999999993`2.0530784434834195}, {
     0.6798999999999999488`3.832445041174111, 0.0106`2.0253058652647704}}, {
    "", "aug-cc-pVTZ", {
     0``4., 0.0177000000000000005`2.2479732663618064}, \
{-0.0185999999999999499`2.269512944217915, 
      2.009300000000000086`4.303044784243365}, {
     0.5966000000000000192`3.7756832490260437, 
      0.0120999999999999996`2.08278537031645}, {
     0.6765999999999998682`3.8303319934519617, 
      0.0114999999999999998`2.060697840353612}}, {
    "", "aug-cc-pVQZ", {
     0``4., 0.0177999999999999999`2.2504200023088936}, \
{-0.0184999999999999609`2.267171728403013, 
      2.0093999999999998529`4.30306639792351}, {
     0.5969999999999999751`3.7759743311293694, 
      0.0122000000000000008`2.0863598306747484}, {
     0.6770000000000000462`3.8305886686851442, 
      0.0115999999999999992`2.064457989226918}}, {
    "SF-TD-BHHLYP", "6-31+G(d)", {
     0``4., 0.0417999999999999969`2.621176281775035}, {
     0.0636000000000000454`2.803457115648414, 
      2.0169000000000001371`4.304684365974387}, {
     1.3053999999999998938`4.115743608359958, 
      0.0178999999999999992`2.252853030979893}, {
     1.4580999999999999517`4.163787309962003, 
      0.0177000000000000005`2.2479732663618064}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0420999999999999985`2.6242820958356683}, {
     0.0510000000000000453`2.7075701760979367, 
      2.018200000000000216`4.30496420183769}, {
     1.2604999999999999538`4.100542850012465, 
      0.0200000000000000004`2.3010299956639813}, {
     1.437200000000000033`4.157517208532612, 
      0.0175000000000000017`2.2430380486862944}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0427999999999999978`2.6314437690131722}, {
     0.0454000000000000514`2.657055852857104, 
      2.0194999999999998508`4.305243857506007}, {
     1.2491999999999998661`4.096631975558161, 
      0.020799999999999999`2.3180633349627615}, {
     1.4314000000000000057`4.155761012877924, 
      0.0182000000000000009`2.2600713879850747}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0429000000000000006`2.632457292184724}, {
     0.0456000000000000294`2.6589648426644357, 
      2.0196000000000000618`4.305265362023449}, {
     1.250099999999999989`4.09694475517694, 
      0.0208999999999999984`2.320146286111054}, {
     1.4324999999999998845`4.156094630639427, 
      0.0183000000000000003`2.2624510897304293}}, {
    "SF-TD-M06-2X", "6-31+G(d)", {
     0``4., 0.0463000000000000009`2.665580991017953}, {
     0.1015000000000000346`3.0064660422492318, 
      2.0114000000000000767`4.3034984457923136}, {
     1.4760999999999999677`4.169115780235715, 
      0.0111999999999999999`2.0492180226701815}, {
     1.6400000000000001243`4.214843848047698, 
      0.0108000000000000006`2.03342375548695}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0466000000000000025`2.66838591669}, {
     0.0861000000000000099`2.935003151453655, 
      2.0127000000000001556`4.3037790465955315}, {
     1.4191000000000000281`4.152013000050834, 
      0.0137000000000000004`2.1367205671564067}, {
     1.6111999999999999655`4.207149453209543, 0.0106`2.0253058652647704}}, {
    "", "aug-cc-pVTZ", {0``4., 0.047100000000000003`2.673020907128896}, {
     0.0781000000000000028`2.8926510338773, 
      2.0139999999999997904`4.304059466217599}, {
     1.4034999999999999698`4.147212416970458, 
      0.0152999999999999994`2.184691430817599}, {
     1.6022999999999998355`4.2047438326888, 
      0.0120000000000000002`2.0791812460476247}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0473999999999999977`2.675778341674085}, {
     0.0791999999999999926`2.8987251815894934, 
      2.0137000000000000455`4.303994770066042}, {
     1.4077999999999999403`4.148540960867229, 0.0152`2.1818435879447726}, {
     1.6068000000000002281`4.205961823059634, 
      0.0119000000000000009`2.0755469613925306}}, {
    "SF-TD-CAM-B3LYP", "6-31+G(d)", {
     0``4., 0.0218999999999999993`2.340444114840118}, {
     0.0205999999999999517`2.3138672203691524, 
      2.0060999999999999943`4.302352577919563}, {
     0.6030999999999999694`3.7803893284709527, 
      0.0114000000000000004`2.0569048513364727}, {
     0.6716999999999999638`3.8271753482986925, 
      0.0111000000000000005`2.045322978786657}}, {
    "", "aug-cc-pVDZ", {0``4., 0.022200000000000001`2.3463529744506384}, {
     0.0124999999999999556`2.096910013008055, 
      2.0074999999999998401`4.302655553950719}, {
     0.5852000000000000535`3.7673043174532737, 
      0.0126000000000000001`2.100370545117563}, {
     0.6664999999999999813`3.823800153749878, 
      0.0111000000000000005`2.045322978786657}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0227000000000000014`2.3560258571931225}, {
     0.0103000000000000869`2.012837224705176, 
      2.0081999999999999851`4.30280696274142}, {
     0.580099999999999949`3.7635028654675966, 
      0.0131999999999999999`2.1205739312058496}, {
     0.6635000000000000897`3.821840927200454, 
      0.0115999999999999992`2.064457989226918}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0228000000000000008`2.357934847000454}, {
     0.0102999999999999758`2.012837224705171, 
      2.0083000000000001961`4.3028285882602555}, {
     0.580399999999999916`3.7637274037656985, 
      0.0131999999999999999`2.1205739312058496}, {
     0.6638000000000000567`3.822037248072585, 
      0.0115999999999999992`2.064457989226918}}, {
    "SF-TD-\[Omega]B97X-V", "6-31+G(d)", {
     0``4., 0.0234000000000000007`2.369215857410143}, {
     0.0403999999999999915`2.6063813651106047, 
      2.0053999999999998494`4.302201010605382}, {
     0.5998999999999999888`3.778078861937455, 
      0.0089999999999999993`1.9542425094393248}, {
     0.6704999999999999849`3.826398782187618, 
      0.0085000000000000006`1.9294189257142926}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0242999999999999987`2.385606273598312}, {
     0.0285999999999999588`2.4563660331290427, 
      2.0074000000000000732`4.302633919813779}, {
     0.5762999999999999234`3.760648619581356, 
      0.0112999999999999993`2.0530784434834195}, {
     0.6643999999999999906`3.8224296237793567, 
      0.0091999999999999998`1.9637878273455551}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0246999999999999997`2.392696953259666}, {
     0.026499999999999968`2.423245873936807, 
      2.0081000000000002181`4.302785336145699}, {
     0.571699999999999986`3.7571681922142726, 
      0.0119000000000000009`2.0755469613925306}, {
     0.6618000000000000549`3.8207267628238344, 
      0.0095999999999999992`1.9822712330395682}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0247999999999999991`2.3944516808262164}, {
     0.026499999999999968`2.423245873936807, 
      2.0081999999999999851`4.30280696274142}, {
     0.5719999999999998419`3.757396028793024, 
      0.0120000000000000002`2.0791812460476247}, {
     0.6620999999999999108`3.8209235878813175, 
      0.0097000000000000003`1.9867717342662448}}, {
    "SF-TD-M11", "6-31+G(d)", {
     0``4., 0.0415999999999999981`2.6190933306267423}, {
     0.1018000000000000016`3.00774777800074, 
      2.0087000000000001521`4.302915079568861}, {
     1.2364999999999999325`4.092194120697316, 
      0.0138999999999999992`2.143014800254095}, {
     1.3738999999999998991`4.13795512353236, 
      0.0137000000000000004`2.1367205671564067}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0425000000000000031`2.628388930050311}, {
     0.0868000000000000022`2.9385197251764916, 
      2.0110999999999998877`4.303433666006204}, {
     1.196299999999999919`4.077840102734993, 
      0.0166000000000000002`2.220108088040055}, {
     1.3617999999999998995`4.134113329842324, 
      0.0137999999999999998`2.1398790864012365}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0427999999999999978`2.6314437690131722}, {
     0.0813000000000000111`2.910090545594068, 
      2.0116999999999998217`4.303563215917248}, {
     1.187799999999999967`4.074743320941003, 
      0.0168999999999999984`2.2278867046136734}, {
     1.3587000000000000188`4.13312357540262, 
      0.0137999999999999998`2.1398790864012365}}, {
    "", "aug-cc-pVQZ", {0``4., 0.042599999999999999`2.629409599102719}, {
     0.0798999999999999988`2.9025467793139916, 
      2.0118000000000000327`4.3035848038124636}, {
     1.1847999999999998533`4.073645045513152, 
      0.0166999999999999996`2.2227164711475833}, {
     1.356999999999999984`4.132579847659737, 
      0.0134000000000000005`2.1271047983648077}}, {
    "SF-TD-LC-\[Omega]PBE08", "6-31+G(d)", {
     0``4., 0.0299999999999999989`2.4771212547196626}, {
     0.0781000000000000583`2.8926510338773004, 
      2.0066000000000001613`4.302460807910379}, {
     0.5929999999999999716`3.7730546933642626, 
      0.0103000000000000001`2.012837224705172}, {
     0.6629000000000000448`3.8214480190175304, 
      0.0094999999999999998`1.9777236052888476}}, {
    "", "aug-cc-pVDZ", {0``4., 0.0318999999999999978`2.503790683057181}, {
     0.0599000000000000643`2.7774268223893115, 
      2.0112000000000000988`4.303455260341883}, {
     0.5630999999999999339`3.7505855273410087, 
      0.0143000000000000002`2.155336037465062}, {
     0.6592999999999999972`3.819083075743703, 
      0.0109999999999999994`2.041392685158225}}, {
    "", "aug-cc-pVTZ", {0``4., 0.0326999999999999999`2.5145477526602864}, {
     0.0582000000000000295`2.764922984649889, 
      2.0123999999999999666`4.303714308653711}, {
     0.5605999999999999872`3.748653093424267, 
      0.0152999999999999994`2.184691430817599}, {
     0.6584000000000000963`3.8184898222042136, 
      0.0117999999999999997`2.0718820073061255}}, {
    "", "aug-cc-pVQZ", {0``4., 0.0328000000000000028`2.5158738437116788}, {
     0.0582000000000000295`2.764922984649889, 
      2.0125000000000001776`4.303735889039906}, {
     0.5607999999999999652`3.748808004958602, 
      0.0152999999999999994`2.184691430817599}, {
     0.6586000000000000743`3.818621726375889, 
      0.0119000000000000009`2.0755469613925306}}, {
    "SF-ADC(2)-s", "6-31+G(d)", {0``4., ""}, {
     0.3445749999999999647`3.5372837648244126, ""}, {
     1.7597030000000000172`4.2454393744360255, ""}, {
     2.0955059999999998688`4.3212889086741155, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     0.2689099999999999824`3.429606952703283, ""}, {
     1.656021999999999883`4.219066102023219, ""}, {
     1.8937120000000000619`4.277313931203006, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     0.2563389999999999835`3.4088146857639363, ""}, {
     1.6124190000000000467`4.207477907036545, ""}, {
     1.844238000000000044`4.265816966292956, ""}}, {"", "aug-cc-pVQZ"}, {
    "SF-ADC(2)-x", "6-31+G(d)", {0``4., ""}, {
     0.2638040000000000385`3.4212813763686385, ""}, {
     1.1813020000000000742`4.072360939245152, ""}, {
     1.9718310000000001114`4.294869690061266, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     0.2161909999999999665`3.3348376103772623, ""}, {
     1.1070569999999999578`4.04416998234952, ""}, {
     1.7598389999999999311`4.245472937922166, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     0.2115180000000000393`3.3253473313708346, ""}, {
     1.0909590000000000121`4.037808429407458, ""}, {
     1.7308319999999999261`4.238254915932136, ""}}, {
    "SF-ADC(3)", "6-31+G(d)", {0``4., ""}, {
     0.1231969999999999732`3.090600132347002, ""}, {
     1.649732999999999894`4.21741366178383, ""}, {
     2.0781279999999999752`4.317672293934178, ""}}, {
    "", "aug-cc-pVDZ", {0``4., ""}, {
     0.0879939999999999889`2.9444530601532546, ""}, {
     1.5706850000000001089`4.196089096256561, ""}, {
     1.877595000000000125`4.2736019200740785, ""}}, {
    "", "aug-cc-pVTZ", {0``4., ""}, {
     0.0794249999999999956`2.899957223499185, ""}, {
     1.5754280000000000506`4.197398559895156, ""}, {
     1.8532420000000000559`4.267932134052997, ""}}}, 
   TableHeadings -> {
    None, {"Method", "Basis", 
      "1\!\(\*SuperscriptBox[\(\\ \), \(1\)]\)\!\(\*SubscriptBox[\(B\), \(1  \
g\)]\)", "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(3\)]\)\!\
\(\*SubscriptBox[\(A\), \(2  g\)]\)", 
      "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(1  g\)]\)", 
      "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(2  g\)]\)"}}, TableAlignments -> 
   Left]]], "Output",
 CellChangeTimes->{
  3.827380561694721*^9, {3.827380664051066*^9, 3.827380694134598*^9}, 
   3.828426960656591*^9},
 CellLabel->
  "Out[65]//TableForm=",ExpressionUUID->"6f94d4c2-5a26-49ac-aa70-\
234050744f9f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"SetAccuracy", "[", 
    RowBox[{"CBDD4h", ",", "4"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Method\>\"", ",", "\"\<Basis\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(3\)]\)\!\(\*SubscriptBox[\(A\), \(2  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(A\), \(1  g\)]\)\>\"", ",", 
        "\"\<1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \
\(1\)]\)\!\(\*SubscriptBox[\(B\), \(2  g\)]\)\>\""}], "}"}]}], "}"}]}], ",", 
   " ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8124556299606953`*^9, 3.812456068618113*^9}, {
   3.8124561363369207`*^9, 3.812456197829088*^9}, {3.8124562429685*^9, 
   3.812456260620059*^9}, {3.812456331353037*^9, 3.812456384093768*^9}, {
   3.812456573030534*^9, 3.8124566133288307`*^9}, 3.812456659150004*^9, {
   3.812456797405002*^9, 3.8124568446428843`*^9}, {3.81245701524162*^9, 
   3.812457045598267*^9}, 3.812457174657404*^9, {3.812457293034042*^9, 
   3.812457340284532*^9}, 3.8124573713758183`*^9, {3.8124574135109253`*^9, 
   3.812457467988901*^9}, {3.812457525670442*^9, 3.8124575800592833`*^9}, {
   3.812471509708454*^9, 3.8124715175446997`*^9}, {3.812471613960926*^9, 
   3.812471760379608*^9}, {3.812471807962068*^9, 3.812471816235973*^9}, {
   3.812471988217773*^9, 3.812472032321349*^9}, {3.812472081700213*^9, 
   3.812472104421781*^9}, {3.812905577293921*^9, 3.812905591905593*^9}, {
   3.812905701723777*^9, 3.812905738566313*^9}, 3.812906324680492*^9, {
   3.812906383422841*^9, 3.812906439251058*^9}, {3.8129072174245987`*^9, 
   3.8129072178235207`*^9}, {3.81290783650852*^9, 3.812907839973118*^9}, {
   3.812908188519864*^9, 3.812908188749086*^9}, {3.812908398082901*^9, 
   3.812908398483513*^9}, {3.812908465537078*^9, 3.812908481116406*^9}, {
   3.8129085173473454`*^9, 3.812908557109565*^9}, {3.812908776475946*^9, 
   3.812908776824605*^9}, {3.812908820719648*^9, 3.812908909368223*^9}, 
   3.8133809253635273`*^9, {3.813402482937264*^9, 3.813402484919916*^9}, {
   3.815727989997191*^9, 3.815728003482004*^9}, {3.819644301685548*^9, 
   3.819644305685028*^9}, {3.819644418060289*^9, 3.8196444431646976`*^9}, 
   3.819644476706355*^9, {3.81964450923114*^9, 3.8196445638056383`*^9}, {
   3.8196446098161077`*^9, 3.819644616512904*^9}, 3.819644758713471*^9, {
   3.819644805886161*^9, 3.8196448188048973`*^9}, {3.819645044650301*^9, 
   3.8196450641286383`*^9}, 3.819646437998444*^9, {3.8196466447559643`*^9, 
   3.8196466485827103`*^9}, {3.819962444574202*^9, 3.8199624447437763`*^9}, {
   3.820119620567943*^9, 3.820119636432824*^9}, {3.820119774500806*^9, 
   3.820119797451242*^9}, {3.820394165740387*^9, 3.820394165850604*^9}, {
   3.8203942656540833`*^9, 3.820394277151956*^9}, 3.822208994665655*^9, {
   3.824617274248993*^9, 3.824617280677133*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"a64c1c75-5181-46a3-916b-6c0d8d53cd2a"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Method\"\>",
       HoldForm], 
      TagBox["\<\"Basis\"\>",
       HoldForm], 
      TagBox["\<\"1 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(3\\)]\\)\\!\\(\
\\*SubscriptBox[\\(A\\), \\(2  g\\)]\\)\"\>",
       HoldForm], 
      TagBox["\<\"1 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\
\\*SubscriptBox[\\(A\\), \\(1  g\\)]\\)\"\>",
       HoldForm], 
      TagBox["\<\"1 \
\\!\\(\\*SuperscriptBox[\\(\[InvisiblePrefixScriptBase]\\), \\(1\\)]\\)\\!\\(\
\\*SubscriptBox[\\(B\\), \\(2  g\\)]\\)\"\>",
       HoldForm]},
     {"\<\"CCSD\"\>", "\<\"6-31+G(d)\"\>", 
      "0.1479999999999999927`3.170261715394957", 
      "1.7880000000000000338`4.252367514459899", "\<\"\"\>"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "0.1000000000000000056`3.", 
      "1.6499999999999999112`4.217483944213906", "\<\"\"\>"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.0850000000000000061`2.9294189257142924", 
      "1.6000000000000000888`4.204119982655925", "\<\"\"\>"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.0840000000000000052`2.9242792860618816", 
      "1.5880000000000000782`4.200850498091078", "\<\"\"\>"},
     {"\<\"CC3\"\>", "\<\"6-31+G(d)\"\>", "\<\"\"\>", 
      "1.8089999999999999414`4.257438566859814", 
      "2.8359999999999998543`4.452706226511029"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", "\<\"\"\>", 
      "1.6950000000000000622`4.2291697025391", 
      "2.6459999999999999076`4.422589839851482"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", "\<\"\"\>", 
      "1.6619999999999999218`4.220631019448092", 
      "2.7200000000000001954`4.434568904034198"},
     {"\<\"CCSDT\"\>", "\<\"6-31+G(d)\"\>", 
      "0.2099999999999999922`3.322219294733919", 
      "1.7509999999999998899`4.243286146083446", 
      "2.5649999999999999467`4.409087369447835"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.1650000000000000078`3.2174839442139063", 
      "1.6590000000000000302`4.2198463860243605", 
      "2.4500000000000001776`4.389166084364533"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.1489999999999999936`3.173186268412274", 
      "1.6310000000000000053`4.212453961040276", 
      "2.5369999999999999218`4.404320467221731"},
     {"\<\"CC4\"\>", "\<\"6-31+G(d)\"\>", "\<\"\"\>", 
      "1.6040000000000000924`4.205204363948145", 
      "2.1209999999999999964`4.326540668516562"},
     {"\<\"CCSDTQ\"\>", "\<\"6-31+G(d)\"\>", 
      "0.2049999999999999878`3.311753861055754", 
      "1.5929999999999999716`4.202215775801132", 
      "2.133999999999999897`4.329194415088451"},
     {"\<\"SA2-CASSCF(4,4)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.4470000000000000084`3.6503075231319366", 
      "2.2570000000000001172`4.353531559077762", 
      "3.5489999999999999325`4.550105999347593"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.4380000000000000004`3.6414741105040997", 
      "2.2400000000000002132`4.350248018334163", 
      "3.4430000000000000604`4.536937022704674"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.4339999999999999969`3.6374897295125104", 
      "2.2339999999999999858`4.349083168779591", 
      "3.4239999999999999325`4.534533756005115"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.4349999999999999978`3.6384892569546374", 
      "2.2349999999999998757`4.349277527467955", 
      "3.4270000000000000462`4.534914104429867"},
     {"\<\"CASPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.1759999999999999898`3.2455126678141495", 
      "1.5880000000000000782`4.200850498091078", 
      "1.8990000000000000213`4.278524964737017"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.1370000000000000107`3.1367205671564067", 
      "1.5400000000000000355`4.187520720836463", 
      "1.7079999999999999627`4.232487866352987"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.1280000000000000027`3.1072099696478683", 
      "1.5060000000000000053`4.177824971864681", 
      "1.6350000000000000089`4.213517756996305"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.1280000000000000027`3.1072099696478683", 
      "1.4979999999999999982`4.175511813363447", 
      "1.6120000000000000995`4.207365037469072"},
     {"\<\"SC-NEVPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.0830000000000000043`2.919078092376074", 
      "1.5200000000000000178`4.181843587944773", 
      "1.3799999999999998934`4.139879086401237"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.0369999999999999982`2.568201724066995", 
      "1.4650000000000000799`4.165837624690128", 
      "1.1399999999999999023`4.056904851336473"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.0240000000000000005`2.380211241711606", 
      "1.4279999999999999361`4.154728207440155", 
      "1.0549999999999999378`4.023252459633712"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.0240000000000000005`2.380211241711606", 
      "1.4199999999999999289`4.152288344383057", 
      "1.0300000000000000266`4.012837224705172"},
     {"\<\"PC-NEVPT2(4,4)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.0850000000000000061`2.9294189257142924", 
      "1.4959999999999999964`4.174931593528442", 
      "1.3289999999999999591`4.123524980942732"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.0389999999999999999`2.591064607026499", 
      "1.4399999999999999467`4.158362492095249", 
      "1.0880000000000000782`4.036628895362161"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.0259999999999999988`2.4149733479708173", 
      "1.4030000000000000249`4.14705767102836", 
      "1.0029999999999998916`4.001300933020418"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.0259999999999999988`2.4149733479708173", 
      "1.3950000000000000178`4.144574207609616", 
      "0.9769999999999999796`3.989894563718773"},
     {"\<\"MRCI(4,4)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.2969999999999999862`3.4727564493172127", 
      "1.8609999999999999876`4.269746373130767", 
      "2.5710000000000001741`4.41010207664286"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.2730000000000000204`3.436162647040756", 
      "1.8229999999999999538`4.260786668654976", 
      "2.4190000000000000391`4.383635868361879"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.2710000000000000187`3.432969290874406", 
      "1.8240000000000000657`4.261024833992398", 
      "2.4150000000000000355`4.382917135087531"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.2730000000000000204`3.436162647040756", 
      "1.8249999999999999556`4.261262868792493", 
      "2.4129999999999998117`4.382557321908785"},
     {"\<\"SA2-CASSCF(12,12)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.3860000000000000098`3.5865873046717547", 
      "1.9739999999999999769`4.295347148333618", 
      "2.7360000000000002096`4.437116093048078"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.3739999999999999991`3.5728716022004803", 
      "1.9470000000000000639`4.289365951520032", 
      "2.6490000000000000213`4.423081958297231"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.3699999999999999956`3.568201724066995", 
      "1.9430000000000000604`4.2884728005997825", 
      "2.633999999999999897`4.420615770625765"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.3709999999999999964`3.5693739096150456", 
      "1.9450000000000000622`4.288919605661727", 
      "2.6370000000000000107`4.421110129793434"},
     {"\<\"CASPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.2349999999999999867`3.3710678622717363", 
      "1.6350000000000000089`4.213517756996305", 
      "2.1699999999999999289`4.33645973384853"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.2030000000000000138`3.307496037913213", 
      "1.5880000000000000782`4.200850498091078", 
      "2.0150000000000001243`4.304275050477128"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.182999999999999996`3.2624510897304297", 
      "1.5380000000000000338`4.186956335465412", 
      "1.9259999999999999343`4.284656282788515"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.1789999999999999925`3.2528530309798933", 
      "1.5220000000000000195`4.182414652434554", 
      "1.8979999999999999094`4.278296208091273"},
     {"\<\"SC-NEVPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.2179999999999999993`3.338456493604605", 
      "1.6439999999999999059`4.215901813204032", 
      "2.1429999999999997939`4.331022171041829"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.1890000000000000013`3.276461804173244", 
      "1.6000000000000000888`4.204119982655925", 
      "1.991000000000000103`4.299071260027409"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.1650000000000000078`3.2174839442139063", 
      "1.5460000000000000409`4.189209489582306", 
      "1.8919999999999999041`4.276921132065774"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.1600000000000000033`3.2041199826559246", 
      "1.5289999999999999147`4.18440748541232", 
      "1.8620000000000000995`4.269979676645324"},
     {"\<\"PC-NEVPT2(12,12)\"\>", "\<\"6-31+G(d)\"\>", 
      "0.1890000000000000013`3.276461804173244", 
      "1.5789999999999999591`4.198382130008294", 
      "2.0200000000000000178`4.305351369446623"},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      "0.1559999999999999998`3.1931245983544616", 
      "1.5300000000000000266`4.184691430817599", 
      "1.8540000000000000924`4.2681097298084785"},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      "0.1310000000000000053`3.117271295655764", 
      "1.4759999999999999787`4.169086357487023", 
      "1.7560000000000000053`4.244524511570083"},
     {"\<\"\"\>", "\<\"aug-cc-pVQZ\"\>", 
      "0.1260000000000000009`3.1003705451175625", 
      "1.4599999999999999645`4.164352855784437", 
      "1.7270000000000000906`4.2372923375674585"},
     {"\<\"CIPSI\"\>", "\<\"6-31+G(d)\"\>", 
      InterpretationBox[
       TemplateBox[{"0.2010", "0.0030"},
        "Around"],
       Around[
       0.201000000000000012`3.3031960574204886, 
        0.0030000000000000001`1.4771212547196624]], 
      InterpretationBox[
       TemplateBox[{"1.602", "0.007"},
        "Around"],
       Around[
       1.6020000000000000906`4.204662511748219, 
        0.0070000000000000001`1.8450980400142567]], 
      InterpretationBox[
       TemplateBox[{"2.13", "0.04"},
        "Around"],
       Around[
       2.1259999999999998899`4.3275632601872775, 
        0.0410000000000000017`2.6127838567197355]]},
     {"\<\"\"\>", "\<\"aug-cc-pVDZ\"\>", 
      InterpretationBox[
       TemplateBox[{"0.1570", "0.0030"},
        "Around"],
       Around[
       0.1570000000000000007`3.195899652409234, 
        0.0030000000000000001`1.4771212547196624]], 
      InterpretationBox[
       TemplateBox[{"1.587", "0.005"},
        "Around"],
       Around[
       1.5869999999999999662`4.200576926754849, 
        0.0050000000000000001`1.6989700043360187]], 
      InterpretationBox[
       TemplateBox[{"2.102", "0.027"},
        "Around"],
       Around[
       2.1019999999999998685`4.322632711692223, 
        0.0269999999999999997`2.4313637641589874]]},
     {"\<\"\"\>", "\<\"aug-cc-pVTZ\"\>", 
      InterpretationBox[
       TemplateBox[{"0.18", "0.04"},
        "Around"],
       Around[
       0.1759999999999999898`3.2455126678141495, 
        0.0400000000000000008`2.602059991327962]], 
      InterpretationBox[
       TemplateBox[{"1.66", "0.04"},
        "Around"],
       Around[
       1.6590000000000000302`4.2198463860243605, 
        0.0439999999999999974`2.643452676486187]], "\<\"\"\>"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Method", "Basis", 
       "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(3\)]\)\!\(\
\*SubscriptBox[\(A\), \(2  g\)]\)", 
       "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(1\)]\)\!\(\
\*SubscriptBox[\(A\), \(1  g\)]\)", 
       "1 \!\(\*SuperscriptBox[\(\[InvisiblePrefixScriptBase]\), \(1\)]\)\!\(\
\*SubscriptBox[\(B\), \(2  g\)]\)"}}, TableAlignments -> Left]]]], "Output",
 CellChangeTimes->{
  3.820386261119042*^9, 3.820386308590036*^9, {3.82038666589384*^9, 
   3.820386671252273*^9}, 3.8203875073095703`*^9, {3.820387663511159*^9, 
   3.8203876905027437`*^9}, {3.820388098848071*^9, 3.8203881096802692`*^9}, {
   3.820388142944037*^9, 3.8203881538252077`*^9}, 3.820393447224986*^9, 
   3.820394166176065*^9, 3.820394278565033*^9, 3.8204809981875134`*^9, 
   3.822208876414875*^9, 3.822208995715869*^9, 3.8225345151311626`*^9, 
   3.822534962579447*^9, 3.822535260069734*^9, 3.8226680926568213`*^9, 
   3.8226686319292297`*^9, {3.8235302516364937`*^9, 3.823530264731718*^9}, 
   3.823601421186048*^9, 3.823841188055235*^9, 3.823841480873786*^9, {
   3.8246170711267757`*^9, 3.824617089179977*^9}, {3.824617278068821*^9, 
   3.8246172809312143`*^9}, 3.825752286564755*^9, {3.825758493325074*^9, 
   3.825758503859522*^9}},
 CellLabel->
  "Out[6]//TableForm=",ExpressionUUID->"e2124d33-2d89-4e1c-8d3a-3faa59b02399"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.822208995773974*^9},ExpressionUUID->"91058d2c-e268-4c8b-8ff4-\
d01b8a02c12e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Autoisomerisation", "Section",
 CellChangeTimes->{{3.823483870042284*^9, 
  3.8234838734013023`*^9}},ExpressionUUID->"5e574607-3b56-4320-867c-\
484c37c5330b"],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.815728210943774*^9, 
  3.815728212904736*^9}},ExpressionUUID->"1c76f8e7-0977-47de-b4f9-\
95febd6ffe98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Auto", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<CASSCF(12,12)\>\"", ",", "10.19", ",", "10.75", ",", "11.59", ",", 
       "11.62"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CASPT2(12,12)\>\"", ",", "7.24", ",", "7.53", ",", "8.51", ",", 
       "8.71"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<NEVPT2(12,12)\>\"", ",", "7.12", ",", "7.33", ",", "8.28", ",", 
       "8.49"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSD\>\"", ",", "8.31", ",", "8.80", ",", "9.88", ",", "10.10"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CC3\>\"", ",", "6.59", ",", "6.89", ",", "7.88", ",", "8.06"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSDT\>\"", ",", "7.26", ",", "7.64", ",", "8.68", ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CC4\>\"", ",", "7.40", ",", "7.78", ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<CCSDTQ\>\"", ",", "7.51", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<CIPSI\>\"", ",", 
       RowBox[{"Around", "[", 
        RowBox[{"7.91", " ", ",", " ", "0.21"}], "]"}], ",", 
       RowBox[{"Around", "[", 
        RowBox[{"8.58", ",", "0.14"}], "]"}], ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",\

 CellChangeTimes->CompressedData["
1:eJwdz31MzHEcB/DrDJWTVok7OZfSdHceim70pF8rYnmYoVituh5MuGh5qK7r
UsK4ViKM81BMeTgqD8nDFW49zKmulhWWh9TN/VbSkF8PfN+/Pz57bZ/3Pp/P
Pq7ylM2JXA6HE0oKxqusXiQeoKkjWkYPKz7kvYb9KTMMsFXSse4bcUXUtHBo
aCi05hykKXEhw4N1/A2GcGK/IL0FChM2dsCDPwa74fklD3qhvc33cejcVcVd
T3RX2AihqelN1yniZfmP9zAw3NEMk+pvMbDZdMFRQyzNnuQEuT8nRt4SUytk
DOyLzJW0EJ/LbiyC3erAXTCen6aCFt7aPLhu6/GzsJLq08Lfm2eWwaBq/ztw
z8vHrHSlqBJuuM3Uw0dDixtgwTmFETalqdvhls7J/Wx+hVKasD8wmVUe/dFz
nOinMYhh77MxbyioeLIM9pWkzvI4RNTTrJdmr54LfXNLWUXM5SnLYU65NZTu
nD0dyi562cOBopG50L1tkhCGjOhv+hBd9i8rh9ok/l243c1KB52vDhdtIwYH
uF+E3AnNNbhQfrIMNvrIyqHDqrCHcGnzo1oY4m1shLFGm59Q+fQpPwL3sz4v
gAkLhlgvbXeVsP2xXNbdFUafHcQ10hYZFE3JDYCS0uRgyB0ulp8gjpl48VA/
3aF5y2GaKrGcZ+VoBPm3iEH3z7EG8+f3QMOQklW39krgvnSa+lD+dRWMVAhC
4DvKk5VOqVbBgPYa1oVtV22lGTT179pH1jxDjpWZaGfxsIanvVL9PDOJMX9Y
33iKJ+YpaUodE2olIn46vLEymdh21LcK2h0bnfOYODnjggu8MxCRDUe+lamh
bmVQPjS/ij0O7SWZhdAlrr4WxsyKEjlkkX/1D9zgr0gPa1diq8piC7O++9v6
E0OMYTNgq9jpdiJxgNmhg3tXdryAK+huVu6g4hX0rWswwH35WiNsN0e0wuv2
6s8FxKguxVfY61D8FzLymlHolKm1C82mKUXGJgGUagadook1nVOdoctQvPAM
kWdxFMGEtJ5YqJqmjINJXjd67mFe1/wF/gde1jbR
  "],
 CellLabel->"In[3]:=",ExpressionUUID->"1606e71a-fdd3-4bff-84a4-4cf2d64faef5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"SetAccuracy", "[", 
    RowBox[{"Auto", ",", "3"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Method\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<aug-cc-pVDZ\>\"",
         ",", "\"\<aug-cc-pVTZ\>\"", ",", "\"\<aug-cc-pVQZ\>\""}], "}"}]}], 
     "}"}]}], ",", " ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8124556299606953`*^9, 3.812456068618113*^9}, {
   3.8124561363369207`*^9, 3.812456197829088*^9}, {3.8124562429685*^9, 
   3.812456260620059*^9}, {3.812456331353037*^9, 3.812456384093768*^9}, {
   3.812456573030534*^9, 3.8124566133288307`*^9}, 3.812456659150004*^9, {
   3.812456797405002*^9, 3.8124568446428843`*^9}, {3.81245701524162*^9, 
   3.812457045598267*^9}, 3.812457174657404*^9, {3.812457293034042*^9, 
   3.812457340284532*^9}, 3.8124573713758183`*^9, {3.8124574135109253`*^9, 
   3.812457467988901*^9}, {3.812457525670442*^9, 3.8124575800592833`*^9}, {
   3.812471509708454*^9, 3.8124715175446997`*^9}, {3.812471613960926*^9, 
   3.812471760379608*^9}, {3.812471807962068*^9, 3.812471816235973*^9}, {
   3.812471988217773*^9, 3.812472032321349*^9}, {3.812472081700213*^9, 
   3.812472104421781*^9}, {3.812905577293921*^9, 3.812905591905593*^9}, {
   3.812905701723777*^9, 3.812905738566313*^9}, 3.812906324680492*^9, {
   3.812906383422841*^9, 3.812906439251058*^9}, {3.8129072174245987`*^9, 
   3.8129072178235207`*^9}, {3.81290783650852*^9, 3.812907839973118*^9}, {
   3.812908188519864*^9, 3.812908188749086*^9}, {3.812908398082901*^9, 
   3.812908398483513*^9}, {3.812908465537078*^9, 3.812908481116406*^9}, {
   3.8129085173473454`*^9, 3.812908557109565*^9}, {3.812908776475946*^9, 
   3.812908776824605*^9}, {3.812908820719648*^9, 3.812908909368223*^9}, 
   3.8133809253635273`*^9, {3.813402482937264*^9, 3.813402484919916*^9}, {
   3.815727989997191*^9, 3.815728003482004*^9}, {3.819644301685548*^9, 
   3.819644305685028*^9}, {3.819644418060289*^9, 3.8196444431646976`*^9}, 
   3.819644476706355*^9, {3.81964450923114*^9, 3.8196445638056383`*^9}, {
   3.8196446098161077`*^9, 3.819644616512904*^9}, 3.819644758713471*^9, {
   3.819644805886161*^9, 3.8196448188048973`*^9}, {3.819645044650301*^9, 
   3.8196450641286383`*^9}, 3.819646437998444*^9, {3.8196466447559643`*^9, 
   3.8196466485827103`*^9}, {3.819962444574202*^9, 3.8199624447437763`*^9}, {
   3.820119620567943*^9, 3.820119636432824*^9}, {3.820119774500806*^9, 
   3.820119797451242*^9}, {3.822535295408708*^9, 3.822535318649681*^9}, {
   3.82348393279316*^9, 3.823483944885604*^9}, {3.823483979027129*^9, 
   3.8234839805371*^9}, {3.823484162463017*^9, 3.823484164717432*^9}, {
   3.823838909492733*^9, 3.823838910647491*^9}, {3.8238407825759697`*^9, 
   3.823840782712843*^9}, {3.824871610461484*^9, 3.824871614516748*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"4b815da6-1ca4-49fb-9f5e-99820f6623b2"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Method\"\>",
       HoldForm], 
      TagBox["\<\"6-31+G(d)\"\>",
       HoldForm], 
      TagBox["\<\"aug-cc-pVDZ\"\>",
       HoldForm], 
      TagBox["\<\"aug-cc-pVTZ\"\>",
       HoldForm], 
      TagBox["\<\"aug-cc-pVQZ\"\>",
       HoldForm]},
     {"\<\"CASSCF(12,12)\"\>", "10.1899999999999995026`4.008174184006426", 
      "10.75`4.031408464251625", "11.5899999999999998579`4.064083435963596", 
      "11.6199999999999992184`4.065206128054312"},
     {"\<\"CASPT2(12,12)\"\>", "7.2400000000000002132`3.859738566197147", 
      "7.5300000000000002487`3.8767949762007006", 
      "8.5099999999999997868`3.929929560084588", 
      "8.7100000000000008527`3.9400181550076634"},
     {"\<\"NEVPT2(12,12)\"\>", "7.1200000000000001066`3.8524799936368566", 
      "7.3300000000000000711`3.865103974641128", 
      "8.2799999999999993605`3.9180303367848803", 
      "8.4900000000000002132`3.928907690243953"},
     {"\<\"CCSD\"\>", "8.3100000000000004974`3.9196010237841112", 
      "8.8000000000000007105`3.9444826721501687", 
      "9.8800000000000007816`3.9947569445876283", 
      "10.0999999999999996447`4.004321373782643"},
     {"\<\"CC3\"\>", "6.5899999999999998579`3.8188854145940097", 
      "6.8899999999999996803`3.8382192219076257", 
      "7.8799999999999998934`3.896526217489556", 
      "8.0600000000000004974`3.906335041805091"},
     {"\<\"CCSDT\"\>", "7.2599999999999997868`3.8609366207000937", 
      "7.6399999999999996803`3.88309335857569", 
      "8.6799999999999997158`3.938519725176492", "\<\"\"\>"},
     {"\<\"CC4\"\>", "7.4000000000000003553`3.8692317197309762", 
      "7.7800000000000002487`3.890979596989689", "\<\"\"\>", "\<\"\"\>"},
     {"\<\"CCSDTQ\"\>", 
      "7.5099999999999997868`3.8756399370041685", "\<\"\"\>", "\<\"\"\>", "\<\
\"\"\>"},
     {"\<\"CIPSI\"\>", 
      InterpretationBox[
       TemplateBox[{"7.91", "0.21"},
        "Around"],
       Around[
       7.9100000000000001421`3.898176483497677, 
        0.2099999999999999922`2.3222192947339195]], 
      InterpretationBox[
       TemplateBox[{"8.58", "0.14"},
        "Around"],
       Around[
       8.5800000000000000711`3.9334872878487053, 
        0.1400000000000000133`2.146128035678238]], "\<\"\"\>", "\<\"\"\>"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Method", "6-31+G(d)", "aug-cc-pVDZ", "aug-cc-pVTZ", 
       "aug-cc-pVQZ"}}, TableAlignments -> Left]]]], "Output",
 CellChangeTimes->{{3.823483975638871*^9, 3.823483981408504*^9}, {
   3.823484174481164*^9, 3.823484178321521*^9}, 3.8234842929658012`*^9, {
   3.82348435661621*^9, 3.823484375795326*^9}, 3.823669535205727*^9, 
   3.8237000624052067`*^9, 3.82384091847683*^9, 3.823925221541637*^9, 
   3.8248225288271933`*^9, {3.824871605460052*^9, 3.824871614918641*^9}, 
   3.8250411850770607`*^9},
 CellLabel->
  "Out[4]//TableForm=",ExpressionUUID->"37fab670-976c-41e6-a633-c9de5012fcd2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spin-flip methods", "Subsubsection",
 CellChangeTimes->{{3.827482285414358*^9, 
  3.827482296036296*^9}},ExpressionUUID->"39bfcb3c-82e9-40f1-a609-\
e1fd21238104"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"AutoSF", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"SF", "-", "CIS"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<SF-CIS\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "153.66326565"}], "+", "153.66747429"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "153.67593114"}], "+", "153.68042752"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "153.71018192"}], "+", "153.71564099"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "153.71897059"}], "+", "153.72443385"}], ")"}], "*", 
         "627.5091809"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "BLYP"}], "*)"}], "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-BLYP\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.54915957"}], "+", "154.58672843"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.56355220"}], "+", "154.60119345"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.60713863"}], "+", "154.64575345"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.61843598"}], "+", "154.65703656"}], ")"}], "*", 
         "627.5091809"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "B3LYP"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-B3LYP\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.63612319"}], "+", "154.66614385"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.64983891"}], "+", "154.68000617"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.69008595"}], "+", "154.72127116"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.70051522"}], "+", "154.73170498"}], ")"}], "*", 
         "627.5091809"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "PBE0"}], "*)"}], "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-PBE0\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.44443911"}], "+", "154.47201946"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.45975842"}], "+", "154.48741831"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.49342299"}], "+", "154.52212826"}], ")"}], "*", 
         "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.50345761"}], "+", "154.53214416"}], ")"}], "*", 
         "627.5091809"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "BHHLYP"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-BHHLYP\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.55635062"}], "+", "154.57531619"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.56921916"}], "+", "154.58846058"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.60625180"}], "+", "154.62653050"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.61588194"}], "+", "154.63616622"}], ")"}], "*", 
         "627.509180"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "M06", "-", 
        RowBox[{"2", "X"}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-M06-2X\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.60820972"}], "+", "154.62310192"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.62862731"}], "+", "154.64405669"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.66127918"}], "+", "154.67783353"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.67102565"}], "+", "154.68760574"}], ")"}], "*", 
         "627.509180"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "CAM", "-", "B3LYP"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-CAM-B3LYP\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.54266469"}], "+", "154.57168445"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.55611569"}], "+", "154.58528190"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.59673447"}], "+", "154.62697729"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.60720887"}], "+", "154.63744365"}], ")"}], "*", 
         "627.509180"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "wB97X", "-", "V"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-wB97X-V\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.59336359"}], "+", "154.62278545"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.60852651"}], "+", "154.63797921"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.64219264"}], "+", "154.67269733"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.65240885"}], "+", "154.68287894"}], ")"}], "*", 
         "627.509180"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "M11"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-M11\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.56267867"}], "+", "154.58041405"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.57878636"}], "+", "154.59533393"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.62786976"}], "+", "154.64584649"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.63719271"}], "+", "154.65502447"}], ")"}], "*", 
         "627.509180"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "B2PLYP"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-B2PLYP\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.30829625"}], "+", "154.32640924"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.32103373"}], "+", "154.33942962"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.35746882"}], "+", "154.37689835"}], ")"}], "*", 
         "627.509180"}], ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "B2GPPLYP"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-TD-B2GPPLYP\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.23096101"}], "+", "154.24508025"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.24355480"}], "+", "154.25798320"}], ")"}], "*", 
         "627.509180"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.27910591"}], "+", "154.29456080"}], ")"}], "*", 
         "627.509180"}], ",", "\"\<\>\""}], "}"}], ",", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "ADC2", "-", "s"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-ADC2-s\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.1513498777"}], "+", "154.1620167826"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.2001677843"}], "+", "154.2115594045"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.3955261739"}], "+", "154.4092987964"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.4812310714"}], "+", "154.4953400217"}], ")"}], 
         "*", "627.5091809"}]}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "ADC2", "-", "x"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<SF-ADC2-x\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.1736408370"}], "+", "154.1874416597"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.2239437636"}], "+", "154.2385316773"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.4193422119"}], "+", "154.4359204311"}], ")"}], 
         "*", "627.5091809"}], ",", "\"\<\>\""}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"SF", "-", "TD", "-", "ADC3"}], "*)"}], "\[IndentingNewLine]", 
      
      RowBox[{"{", 
       RowBox[{"\"\<SF-ADC3\>\"", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.1831506056"}], "+", "154.1959874239"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.2361527267"}], "+", "154.2501051470"}], ")"}], 
         "*", "627.5091809"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "154.4296710032"}], "+", "154.4449428950"}], ")"}], 
         "*", "627.5091809"}], ",", "\"\<\>\""}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.827482299721491*^9, 3.82748230564396*^9}, {
   3.8274826699629517`*^9, 3.827482682247418*^9}, {3.827824896931892*^9, 
   3.827824905335404*^9}, {3.8278250114058743`*^9, 3.8278250301151133`*^9}, {
   3.827825134566399*^9, 3.8278251747973843`*^9}, {3.827825264585197*^9, 
   3.82782527175636*^9}, {3.827825340694913*^9, 3.827825342634411*^9}, {
   3.827825420530533*^9, 3.827825422470344*^9}, {3.827826453044983*^9, 
   3.827826478448511*^9}, {3.827828788825864*^9, 3.827828792240816*^9}, {
   3.827828842557148*^9, 3.827828890243122*^9}, {3.8278289290860033`*^9, 
   3.827828946172283*^9}, {3.827829037971554*^9, 3.827829040369026*^9}, {
   3.8278293891027117`*^9, 3.827829552087628*^9}, {3.827829695114567*^9, 
   3.827829729960903*^9}, {3.8278297812662373`*^9, 3.827829887558372*^9}, {
   3.8278299257832537`*^9, 3.827829926750765*^9}, {3.827829957200577*^9, 
   3.8278300090351*^9}, {3.827830040328689*^9, 3.827830065117168*^9}, {
   3.827830100240941*^9, 3.827830101928282*^9}, {3.827831074392387*^9, 
   3.827831165728278*^9}, {3.827889293559032*^9, 3.827889317765502*^9}, {
   3.827889350373784*^9, 3.827889358847608*^9}, {3.827889396838183*^9, 
   3.8278894743644447`*^9}, {3.827889579380293*^9, 3.827889760055367*^9}, {
   3.8278910204998083`*^9, 3.827891095347583*^9}, 3.827891135459676*^9, {
   3.8278911803675013`*^9, 3.8278912866655827`*^9}, {3.8278916023954973`*^9, 
   3.827891625844327*^9}, {3.827891675640464*^9, 3.8278919996754303`*^9}, {
   3.827892038481646*^9, 3.827892089101644*^9}, {3.827892121601515*^9, 
   3.827892146450561*^9}, {3.827892180145996*^9, 3.8278921999616823`*^9}, {
   3.827892266148489*^9, 3.827892285971759*^9}, {3.82789238937167*^9, 
   3.827892489563878*^9}, {3.827892547082595*^9, 3.8278925742075653`*^9}, {
   3.827892605847987*^9, 3.827892636736638*^9}, {3.827892676140965*^9, 
   3.827892839923897*^9}, {3.827892982502347*^9, 3.8278930234719133`*^9}, {
   3.82789305835047*^9, 3.8278932031209517`*^9}, {3.827893345474082*^9, 
   3.827893388320796*^9}, {3.8278934277107277`*^9, 3.827893532483468*^9}, {
   3.829639272881027*^9, 3.829639273047887*^9}, {3.829639352073556*^9, 
   3.8296393592033587`*^9}, 3.8296393987147617`*^9, {3.829646530674054*^9, 
   3.8296465750794897`*^9}, {3.8296469007826138`*^9, 3.829646931299312*^9}, {
   3.829647054357782*^9, 3.829647083143505*^9}, {3.829990027448785*^9, 
   3.8299900565963984`*^9}, {3.8299901013780727`*^9, 
   3.8299901026680927`*^9}, {3.8302274662543163`*^9, 3.830227534528288*^9}, {
   3.8302275899525843`*^9, 3.83022759067994*^9}, {3.830227637511037*^9, 
   3.830227639797657*^9}, {3.830227796192348*^9, 3.830227812945609*^9}, {
   3.8302278836137953`*^9, 3.830227932282262*^9}, 3.830228057477911*^9, 
   3.8302294159571657`*^9},
 CellLabel->
  "In[232]:=",ExpressionUUID->"9cdf6e6d-a218-450a-95f8-e3b0048775a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"SetAccuracy", "[", 
    RowBox[{"AutoSF", ",", "3"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Method\>\"", ",", "\"\<6-31+G(d)\>\"", ",", "\"\<aug-cc-pVDZ\>\"",
         ",", "\"\<aug-cc-pVTZ\>\"", ",", "\"\<aug-cc-pVQZ\>\""}], "}"}]}], 
     "}"}]}], ",", " ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.827482323284232*^9, 3.8274823237091837`*^9}, {
  3.827829466654758*^9, 3.8278294734505787`*^9}, {3.82782955663629*^9, 
  3.827829559473291*^9}, {3.827830123216207*^9, 3.827830160115258*^9}, {
  3.8278301906043577`*^9, 3.8278303147342863`*^9}, {3.827831100880259*^9, 
  3.8278311034111967`*^9}, {3.828427008356379*^9, 3.828427014104094*^9}},
 CellLabel->
  "In[233]:=",ExpressionUUID->"224e51d4-fb80-4d27-8453-1ee6ceb061d4"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Method\"\>",
       HoldForm], 
      TagBox["\<\"6-31+G(d)\"\>",
       HoldForm], 
      TagBox["\<\"aug-cc-pVDZ\"\>",
       HoldForm], 
      TagBox["\<\"aug-cc-pVTZ\"\>",
       HoldForm], 
      TagBox["\<\"aug-cc-pVQZ\"\>",
       HoldForm]},
     {"\<\"SF-CIS\"\>", "2.6409602391040123415`3.4217618627488737", 
      "2.8215197308190225201`3.4504830916274543", 
      "3.4256165441761181611`3.534738747401042", 
      "3.4282458076431581162`3.5350719535883286"},
     {"\<\"SF-TD-BLYP\"\>", "23.5748045659425500276`4.37244810114279", 
      "23.6202299555566312961`4.3732841213868605", 
      "24.2311540687960942364`4.384374098981671", 
      "24.2222183380697977384`4.384213914524019"},
     {"\<\"SF-TD-B3LYP\"\>", "18.8382397666717729123`4.27504032014818", 
      "18.9302326126055753264`4.277155950559166", 
      "19.569005583287989225`4.291568757151947", 
      "19.5718607500610097816`4.29163211717909"},
     {"\<\"SF-TD-PBE0\"\>", "17.3069228374492709577`4.238219857389327", 
      "17.3568349176990253113`4.239470532873877", 
      "18.0128204652064489721`4.255581720402629", 
      "18.0010734933489722209`4.255298405010877"},
     {"\<\"SF-TD-BHHLYP\"\>", "11.9010692789363545785`4.075585983331969", 
      "12.074167686244628328`4.081857203048433", 
      "12.7250704084696124596`4.104660193989169", 
      "12.7285719096894514024`4.104779680438199"},
     {"\<\"SF-TD-M06-2X\"\>", "9.344992210408415545`3.9705789437054286", 
      "9.6820775917087082973`3.9859685587341116", 
      "10.3880065939195169733`4.016532216631307", 
      "10.4041586802382823862`4.017206967267237"},
     {"\<\"SF-TD-CAM-B3LYP\"\>", "18.2101658013860401297`4.260313900012341", 
      "18.3020645208075727339`4.262500082048605", 
      "18.9776471790952676599`4.278242368234851", 
      "18.9726020052808301841`4.278126896468112"},
     {"\<\"SF-TD-wB97X-V\"\>", "18.4624872426833128713`4.266290208228786", 
      "18.4818396257905988023`4.266745197380101", 
      "19.1419730080636050218`4.281986699499009", 
      "19.1202611904226493778`4.281493820617095"},
     {"\<\"SF-TD-M11\"\>", "11.1291137607914443208`4.046460581754085", 
      "10.3837520816927124656`4.016354310538907", 
      "11.2805631013730369716`4.052330779232006", 
      "11.1895930955612428193`4.048814293895153"},
     {"\<\"SF-TD-B2PLYP\"\>", "11.3660675022429717984`4.055610230959512", 
      "11.5435898492662101233`4.062340887613776", 
      "12.1922084380831883266`4.0860823787605804", "\<\"\"\>"},
     {"\<\"SF-TD-B2GPPLYP\"\>", "8.859952714631754489`3.94743140407336", 
      "9.0539534527208527237`3.956838257413658", 
      "9.6980853508907571836`3.986686001934359", "\<\"\"\>"},
     {"\<\"SF-ADC2-s\"\>", "6.6935807565410261333`3.8256585074208167", 
      "7.1483462608356180823`3.8542055812605818", 
      "8.6424470638195618477`3.9366367281089816", 
      "8.8534958461111337158`3.9471147878612802"},
     {"\<\"SF-ADC2-x\"\>", "8.6601429482267100468`3.9375250607371717", 
      "9.154049776916723502`3.9616132696579713", 
      "10.4029847509723190058`4.017157961885544", "\<\"\"\>"},
     {"\<\"SF-ADC3\"\>", "8.0552213367964178303`3.906077478216277", 
      "8.7552718340260149432`3.942269634621038", 
      "9.5832523142010419548`3.981512922690945", "\<\"\"\>"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Method", "6-31+G(d)", "aug-cc-pVDZ", "aug-cc-pVTZ", 
       "aug-cc-pVQZ"}}, TableAlignments -> Left]]]], "Output",
 CellChangeTimes->{
  3.8278290079896727`*^9, {3.827829473772744*^9, 3.8278295078951283`*^9}, 
   3.827829559949828*^9, 3.8278296994457912`*^9, 3.827830125168944*^9, 
   3.827830160650173*^9, {3.8278302651439734`*^9, 3.8278302831918793`*^9}, 
   3.827830315515688*^9, 3.8278311038653917`*^9, {3.827831145424098*^9, 
   3.827831168442906*^9}, 3.8278894827897043`*^9, {3.827889746618675*^9, 
   3.827889762558609*^9}, 3.827891291045104*^9, 3.8278918475152063`*^9, 
   3.827892204100655*^9, 3.827892577618187*^9, {3.827892825440534*^9, 
   3.8278928432874327`*^9}, 3.827893206303258*^9, 3.8278935359926977`*^9, {
   3.8284270036463346`*^9, 3.8284270145700912`*^9}, 3.829639409858081*^9, {
   3.829646924755624*^9, 3.829646936556965*^9}, 3.829647085850748*^9, 
   3.8302274558301*^9, 3.830227643490749*^9, 3.8302278162360373`*^9, 
   3.830227935178979*^9, 3.830228060839126*^9, 3.830229419650457*^9},
 CellLabel->
  "Out[233]//TableForm=",ExpressionUUID->"c93ef115-5cf8-4b73-b414-\
5465f153ebdb"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 777},
WindowMargins->{{Automatic, 31}, {0, Automatic}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"7cfd944c-66c4-4b20-856e-aaf3218a9c33"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 157, 3, 98, "Title",ExpressionUUID->"f9fac6ad-b4b0-4fc4-b662-ff26b4fcb383"],
Cell[740, 27, 537, 13, 89, "Input",ExpressionUUID->"73548dbc-1321-4b7c-9133-54658820615c",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1314, 45, 208, 4, 72, "Title",ExpressionUUID->"d98052b5-b8bf-49c7-976f-70f5883fce25"],
Cell[CellGroupData[{
Cell[1547, 53, 302, 8, 68, "Section",ExpressionUUID->"0d5f8085-b423-4bab-b579-a185275ba81f"],
Cell[CellGroupData[{
Cell[1874, 65, 156, 3, 54, "Subsection",ExpressionUUID->"010a9483-a730-4fa6-9b2a-13873895483d"],
Cell[2033, 70, 422, 11, 33, "Text",ExpressionUUID->"203dfa49-b391-422b-90c4-2b6a46c41acd"],
Cell[2458, 83, 618, 12, 196, "Text",ExpressionUUID->"cd19f4a5-5b55-4f6b-ab28-a67e3893faaf"]
}, Closed]],
Cell[CellGroupData[{
Cell[3113, 100, 152, 3, 38, "Subsection",ExpressionUUID->"146f0b45-c767-44b4-adf3-b56aaf7be25a"],
Cell[CellGroupData[{
Cell[3290, 107, 167, 3, 45, "Subsubsection",ExpressionUUID->"85eac05c-0c0d-4570-9562-016c59c123c0"],
Cell[3460, 112, 447, 12, 30, "Input",ExpressionUUID->"5e934c70-0bb3-4c28-a094-c1ba13c9aa1b"],
Cell[3910, 126, 16123, 362, 1627, "Input",ExpressionUUID->"283f461f-fa73-44be-9b2e-3fccbe85020e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20070, 493, 168, 3, 45, "Subsubsection",ExpressionUUID->"496a2a44-bf08-47c1-928f-5e9378cdcbe6"],
Cell[20241, 498, 34689, 895, 1606, "Input",ExpressionUUID->"1f47c0ab-65f0-4e3d-b3bf-78a937e27006"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54979, 1399, 271, 4, 54, "Subsection",ExpressionUUID->"e9b6b4b3-0323-418a-aaa5-63000ac657a3"],
Cell[CellGroupData[{
Cell[55275, 1407, 167, 3, 45, "Subsubsection",ExpressionUUID->"c2a68803-eb09-4af4-95e0-ded4fd26bba2"],
Cell[CellGroupData[{
Cell[55467, 1414, 3016, 47, 56, "Input",ExpressionUUID->"517fe565-dbd4-4f72-9bce-30280a372548"],
Cell[58486, 1463, 7766, 161, 1056, "Output",ExpressionUUID->"2be1012c-883f-42eb-b9e3-ba443f8e5e1d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[66301, 1630, 168, 3, 37, "Subsubsection",ExpressionUUID->"e347b647-085c-4a7a-aacb-16cb902d6b69"],
Cell[CellGroupData[{
Cell[66494, 1637, 1559, 31, 77, "Input",ExpressionUUID->"9326eaa0-341b-4e7e-b996-418c884cb254"],
Cell[68056, 1670, 109780, 2764, 1850, "Output",ExpressionUUID->"97c1e6af-851b-4074-9392-0292b07355a3"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[177897, 4441, 152, 3, 54, "Subsection",ExpressionUUID->"a0eea47c-0908-49f4-87f8-8a7d458525f2"],
Cell[178052, 4446, 2808, 53, 115, "Input",ExpressionUUID->"c94fe3f6-bb2b-425b-9436-cceb389f4f54"],
Cell[180863, 4501, 8151, 180, 283, "Input",ExpressionUUID->"ce9a37c9-f290-4ff9-8e20-fb2ac069191f"],
Cell[189017, 4683, 129, 3, 30, "Input",ExpressionUUID->"afe9eaa6-d491-4b7a-be7d-51d4faa79596"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[189195, 4692, 351, 9, 68, "Section",ExpressionUUID->"031beb2c-3612-4398-bbed-82451a91c66a"],
Cell[CellGroupData[{
Cell[189571, 4705, 156, 3, 54, "Subsection",ExpressionUUID->"e797c147-2261-4ad9-bf30-a876fe039a42"],
Cell[189730, 4710, 475, 11, 33, "Text",ExpressionUUID->"adf832dd-e1af-42ec-b58c-cbbbe9c3192b"],
Cell[190208, 4723, 480, 12, 196, "Text",ExpressionUUID->"c1f07e0a-8d48-41b9-a295-c059851cd566"]
}, Closed]],
Cell[CellGroupData[{
Cell[190725, 4740, 152, 3, 38, "Subsection",ExpressionUUID->"0b0b3775-588f-4d6e-8521-a48a2543bc88"],
Cell[190880, 4745, 15753, 350, 1522, "Input",ExpressionUUID->"0fe9f196-cce7-4233-9666-614981e2b593"],
Cell[206636, 5097, 31172, 807, 1732, "Input",ExpressionUUID->"86ef0a50-daa3-492e-bff4-0c102d15e915"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237845, 5909, 271, 4, 54, "Subsection",ExpressionUUID->"29d9a581-07ec-4f13-a8a0-7566f2d2f79d"],
Cell[CellGroupData[{
Cell[238141, 5917, 1122, 23, 56, "Input",ExpressionUUID->"e8d3b26f-3e58-4a8e-a660-5c2cf37c7202"],
Cell[239266, 5942, 94254, 2369, 1596, "Output",ExpressionUUID->"6f94d4c2-5a26-49ac-aa70-234050744f9f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333557, 8316, 3156, 50, 56, "Input",ExpressionUUID->"a64c1c75-5181-46a3-916b-6c0d8d53cd2a"],
Cell[336716, 8368, 13306, 291, 966, "Output",ExpressionUUID->"e2124d33-2d89-4e1c-8d3a-3faa59b02399"]
}, Open  ]],
Cell[350037, 8662, 147, 3, 52, "Input",ExpressionUUID->"91058d2c-e268-4c8b-8ff4-d01b8a02c12e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[350233, 8671, 164, 3, 67, "Section",ExpressionUUID->"5e574607-3b56-4320-867c-484c37c5330b"],
Cell[CellGroupData[{
Cell[350422, 8678, 152, 3, 54, "Subsection",ExpressionUUID->"1c76f8e7-0977-47de-b4f9-95febd6ffe98"],
Cell[350577, 8683, 2921, 65, 241, "Input",ExpressionUUID->"1606e71a-fdd3-4bff-84a4-4cf2d64faef5"],
Cell[CellGroupData[{
Cell[353523, 8752, 3030, 47, 52, "Input",ExpressionUUID->"4b815da6-1ca4-49fb-9f5e-99820f6623b2"],
Cell[356556, 8801, 3424, 79, 200, "Output",ExpressionUUID->"37fab670-976c-41e6-a633-c9de5012fcd2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360017, 8885, 168, 3, 45, "Subsubsection",ExpressionUUID->"39bfcb3c-82e9-40f1-a609-e1fd21238104"],
Cell[360188, 8890, 15103, 384, 1228, "Input",ExpressionUUID->"9cdf6e6d-a218-450a-95f8-e3b0048775a3"],
Cell[CellGroupData[{
Cell[375316, 9278, 972, 20, 52, "Input",ExpressionUUID->"224e51d4-fb80-4d27-8453-1ee6ceb061d4"],
Cell[376291, 9300, 4971, 99, 330, "Output",ExpressionUUID->"c93ef115-5cf8-4b73-b414-5465f153ebdb"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

